package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.CreditResourceDirectoryService;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.pojos.entity.CreditResourceDirectory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import java.math.BigDecimal;

//@RestController
//@RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"creditresourcedirectory")
//@Api(tags = "CreditResourceDirectoryControllerForApp |一个用来操作-{信用资源目录表}-业务模块的控制器")
public class CreditResourceDirectoryControllerForApp extends BaseUtilController{

        @Autowired
        private CreditResourceDirectoryService creditResourceDirectoryService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{信用资源目录表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{信用资源目录表}-主键删除记录",value = "delete",type = "APP")
        public Map<String, Object> deleteByPrimaryKeyForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = creditResourceDirectoryService.deleteByPrimaryKey(recordid);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{信用资源目录表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{信用资源目录表}-主键查询记录",value = "query",type = "APP")
        public Map<String, Object> selectByPrimaryKeyForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, creditResourceDirectoryService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{信用资源目录表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                        creditResourceDirectoryService.insert(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{信用资源目录表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        Map<String, Object> paramsmap = creditResourceDirectoryService.selectByPrimaryKey(map.get("id")+"");

                        int flag = 0;

                        if( null!=paramsmap &&paramsmap.size()>0) {
                                paramsmap.putAll(map);
                                flag = creditResourceDirectoryService.update(paramsmap);
                        }

                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteByMapForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = creditResourceDirectoryService.deleteByMap(map);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateByMapForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        int flag = creditResourceDirectoryService.updateByMap(map);
                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map查询记录",value = "query",type = "APP")
        public Map<String, Object>  getOneForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, creditResourceDirectoryService.getOne(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map查询所有记录",value = "query",type = "APP")
        public Map<String, Object>  getAllForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, creditResourceDirectoryService.getAll(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map分页记录",value = "query",type = "APP")
        public Map<String, Object>  queryPageForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {

                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = creditResourceDirectoryService.count(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = creditResourceDirectoryService.queryPage(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;


        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map统计查询总数记录",value = "query",type = "APP")
        public Map<String, Object>  countForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATATOTAL, creditResourceDirectoryService.count(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertBatchForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        for(Map<String, Object> map:list){
                                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                        }

                        creditResourceDirectoryService.insertBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteBatchForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        creditResourceDirectoryService.deleteBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateBatchForCreditResourceDirectoryForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        creditResourceDirectoryService.updateBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

}
