package com.philisense.www.controller.app;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.druid.DS;
import com.philisense.www.druid.DataSourceEnum;
import com.philisense.www.service.DataAnalysisChartService;
import com.philisense.www.utils.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/app/api/service/dashboard")
@Api(tags = "DataAnalysisChartControllerForApp |一个用来操作-{大数据分析子系统图表}-业务模块的控制器")
public class DataAnalysisChartControllerForApp extends BaseUtilController{


        @Autowired
        private DataAnalysisChartService dataAnalysisChartService;

        @GetMapping("/selectIndustryRadarChart")
        @ApiOperation(value="根据-{年份}-查询历年行业失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "years", value = "开始年份", required = true,  dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年份}-使用雷达图列举出要统计的失信行业",value = "query",type = "PC")
        public Map<String, Object> selectIndustryRadarChart(HttpServletRequest request , HttpServletResponse response ,@RequestParam("years")String years)
        {

//                List<Map<String, Object>> datas = dataAnalysisChartService.selectMyTest("labelName","产品服务","TRIBT_ANALYSIS.da_label_manage");

                Map<String, Object> result = new HashMap<String, Object>();

                try {

                List<Map<String, String>> list = dataAnalysisChartService.selectIndustryNumChart(years);
                List<String> rq = list.stream().map(q -> q.get("dates")).distinct().collect(Collectors.toList());
                List<String> hy = list.stream().map(y -> y.get("hyName")).distinct().collect(Collectors.toList());

                for(int y=0;y<rq.size();y++)
                {
                   String dates = rq.get(y);
                   List<Map<String, String>> year = list.stream().filter(a -> a.get("dates").toString().equals(dates)).collect(Collectors.toList());
                   result.put("data"+dates, year);
                }

                result.put("rq", rq);
                result.put("hy", hy);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                }catch(Exception e){

                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

                }
                return result;
        }

        @GetMapping("/selectEnterpriseAddressRadarChart")
        @ApiOperation(value="根据-{年份}-查询历年企业失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "years", value = "开始年份", required = true,  dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年份}-使用雷达图列举出要统计的失信企业",value = "query",type = "PC")
        public Map<String, Object> selectEnterpriseAddressRadarChart(HttpServletRequest request , HttpServletResponse response ,@RequestParam("years")String years)
        {

                Map<String, Object> result = new HashMap<String, Object>();

                try {

                        List<Map<String, String>> list = dataAnalysisChartService.selectEnterpriseAddressNumChart(years);
                        List<String> rq = list.stream().map(q -> q.get("dates")).distinct().collect(Collectors.toList());
                        List<String> address = list.stream().map(y -> y.get("address")).distinct().collect(Collectors.toList());

                        for(int y=0;y<rq.size();y++)
                        {
                                String dates = rq.get(y);
                                List<Map<String, String>> year = list.stream().filter(a -> a.get("dates").toString().equals(dates)).collect(Collectors.toList());
                                result.put("data"+dates, year);
                        }

                        result.put("rq", rq);
                        result.put("address", address);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                }catch(Exception e){

                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

                }
                return result;
        }

        @GetMapping("/selectDemo")
        @ApiOperation(value="根据-{年份}-查询历年企业失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "years", value = "开始年份", required = true,  dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年份}-使用雷达图列举出要统计的失信企业",value = "query",type = "PC")
        public Map<String, Object> selectDemo(HttpServletRequest request , HttpServletResponse response ,@RequestParam("years")String years)
        {

                Map<String, Object> result = new HashMap<String, Object>();

                try {

                        List<Map<String, String>> list = dataAnalysisChartService.selectDemo(years);

                        result.put("data", list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                }catch(Exception e){

                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

                }
                return result;
        }

}
