package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.BigDataAnalysisService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"dashboard")
@Api(tags = "BigDataAnalysisControllerForWeb |一个用来操作-{大数据可视化展现下的模块}-业务模块的控制器")
public class BigDataAnalysisControllerForWeb extends BaseUtilController {


        @Autowired
        private BigDataAnalysisService bidDataAnalysisService;


        @PostMapping ("/selectLnhysxtj")
        @ApiOperation(value = "根据-{年份}-查询历年失信统计记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType = "body", name = "years", value = "开始年份", required = true, dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年份}-使用雷达图列举出要统计的失信行业", value = "body", type = "PC")
        public Map<String, Object> selectIndustryRadarChart(HttpServletRequest request, HttpServletResponse response,@RequestBody Map<String, String> map) {

                Map<String, Object> result = new HashMap<String, Object>();

                try {
                        Map<String, Object> maplist = bidDataAnalysisService.selectLnhysxtj(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARESULT, maplist.get("listHy"));
                        result.put(DATALIST, maplist.get("listHyMc"));
                        result.put(PAGINATION, maplist.get("listDq"));
                        result.put(DATARECORD, maplist.get("listDqMc"));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }


                return result;
        }


        @PostMapping ("/selectDzsdfx")
        @ApiOperation(value = "根据-{年月份}-定制深度分析记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType = "body", name = "years", value = "开始年份", required = true, dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年月份}-定制深度分析记录", value = "body", type = "PC")
        public Map<String, Object> selectselectDzsdfx(HttpServletRequest request, HttpServletResponse response,@RequestBody Map<String, String> map) {

                Map<String, Object> result = new HashMap<String, Object>();

                try {
                        List<Map<String, Object>> maplist = bidDataAnalysisService.selectselectDzsdfx(map);
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,maplist);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }


                return result;
        }


        @PostMapping ("/selectGcgzfx")
        @ApiOperation(value = "根据-{年月份和区域代码}-过程跟踪分析", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType = "body", name = "years", value = "开始年份", required = true, dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{年月份和区域代码}-使用区域图显示过程跟踪分析", value = "body", type = "PC")
        public Map<String, Object> selectGcgzfx(HttpServletRequest request, HttpServletResponse response,@RequestBody Map<String, String> map) {

                Map<String, Object> result = new HashMap<String, Object>();

                try {
                        List<Map<String, Object>> maplist = bidDataAnalysisService.selectGcgzfx(map);
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,maplist);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }

                return result;
        }


        @PostMapping ("/selectRqtzfx")
        @ApiOperation(value = "根据-{企企业统一社会代码}-人群特征分析分析", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType = "body", name = "years", value = "开始年份", required = true, dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{企业统一社会代码}-使用人群特征分析分析", value = "body", type = "PC")
        public Map<String, Object> selectRqtzfx(HttpServletRequest request, HttpServletResponse response,@RequestBody Map<String, String> map) {

                Map<String, Object> result = new HashMap<String, Object>();

                try {
                        Map<String, Object> maplist = bidDataAnalysisService.selectRqtzfx(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARESULT, maplist);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }


                return result;
        }
}
