package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.EnterpriseDishonestyTracking;
import com.philisense.www.service.BusinessPortraitsService;
import com.philisense.www.service.EnterpriseDishonestyTrackingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"businessportraits")
@Api(tags = "BusinessPortraitsControllerForWeb|一个用来操作-{企业画像}-业务模块的控制器")
public class BusinessPortraitsControllerForWeb extends BaseUtilController{

        @Autowired
        private EnterpriseDishonestyTrackingService enterpriseDishonestyTrackingService;

        @Autowired
        private BusinessPortraitsService businessPortraitsService;

        @PostMapping("/selectQyxxQuery")
        @ApiOperation(value="根据-{企业信息目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "xydm", value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "zs", value = "住所  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "hymh", value = "行业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "fddbr", value = "法人名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信息目录表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object> selectQyxxQuery(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseDishonestyTrackingService.selectQyxxCount(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseDishonestyTrackingService.selectQyxxQuery(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @GetMapping("/selectPortrait")
        @ApiOperation(value="根据-{主体身份代码}-查询企业画像记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "ztsfdm", value = "主体身份代码", required = true,  dataTypeClass = Integer.class)
        @OperateLog(name = "根据-{主体身份代码}-查询企业画像",value = "query",type = "PC")
        public Map<String, Object> selectPortrait(HttpServletRequest request , HttpServletResponse response ,@RequestParam("ztsfdm")String ztsfdm)
        {

                Map<String, Object> result = new HashMap<String, Object>();

                try {

                        List<Map<String, String>> list0 = businessPortraitsService.selectQyJjxyNum(ztsfdm);
                        List<Map<String, String>> list1 = businessPortraitsService.selectQyDwtzNum(ztsfdm);
                        List<Map<String, String>> list2 = businessPortraitsService.selectQyScjyNum(ztsfdm);
                        List<Map<String, String>> list3 = businessPortraitsService.selectQynbJbxxList(ztsfdm);

                        result.put("jjxy", list0);//经营效益
                        result.put("dwtz", list1);//对外投资
                        result.put("scjy", list2);//生产经营信息
                        result.put("jbxx", list3);//企业年报基本信息

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                }catch(Exception e){

                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

                }
                return result;
        }


}
