package com.philisense.www.controller.web;


import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.CombinationAnalysisService;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.utils.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"combinationanalysis")
@Api(tags = "CombinationAnalysisApplicationControllerForWeb|一个用来操作-{组合应用分析模块}-业务模块的控制器")
public class CombinationAnalysisApplicationControllerForWeb extends BaseUtilController {

    @Autowired
    private CombinationAnalysisService combinationAnalysisService;

    @GetMapping("/selectIndustryBreakOnesPromise")
    @ApiOperation(value="根据-{年月日}-查询历年行业失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="query", name = "startTime", value = "开始时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "endTime", value = "结束时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "qy", value = "区域", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{年月日}-使用环状图列举出要统计的失信行业",value = "query",type = "PC")
    public Map<String, Object> selectIndustryBreakOnesPromise(HttpServletRequest request , HttpServletResponse response , @RequestParam(required = false,name = "startTime")String startTime, @RequestParam(required = false,name = "endTime")String endTime,@RequestParam(required = false,name = "qy")String qy)
    {

        Map<String, Object> result = new HashMap<String, Object>();

        try {

            if(StringUtils.isBlank(qy))
            {
                qy = "54";
            }

            List<Map<String, String>> list = combinationAnalysisService.selectIndustryBreakOnesPromise(startTime, endTime, qy);
            result.put("data", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

        }catch(Exception e){

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

        }
        return result;
    }

    @GetMapping("/selectEnterpriseBreakOnesPromise")
    @ApiOperation(value="根据-{年月日}-查询历年企业失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="query", name = "startTime", value = "开始时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "endTime", value = "结束时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "qy", value = "区域", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{年份}-使用柱状图列举出要统计的失信企业数",value = "query",type = "PC")
    public Map<String, Object> selectEnterpriseBreakOnesPromise(HttpServletRequest request , HttpServletResponse response ,@RequestParam(required = false,name = "startTime")String startTime,@RequestParam(required = false,name = "endTime")String endTime,@RequestParam(required = false,name = "qy")String qy)
    {

        Map<String, Object> result = new HashMap<String, Object>();

        try {

            if(StringUtils.isBlank(qy))
            {
                qy = "54";
            }

            List<Map<String, String>> list = combinationAnalysisService.selectEnterpriseBreakOnesPromise(startTime, endTime, qy);
            result.put("data", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

        }catch(Exception e){

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

        }
        return result;
    }

    @GetMapping("/selectPersonalBreakOnesPromise")
    @ApiOperation(value="根据-{年月日}-查询历年个人失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="query", name = "startTime", value = "开始时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "endTime", value = "结束时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "qy", value = "区域", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{年份}-使用柱状图列举出要统计的失信个人数",value = "query",type = "PC")
    public Map<String, Object> selectPersonalBreakOnesPromise(HttpServletRequest request , HttpServletResponse response ,@RequestParam(required = false,name = "startTime")String startTime,@RequestParam(required = false,name = "endTime")String endTime,@RequestParam(required = false,name = "qy")String qy)
    {

        Map<String, Object> result = new HashMap<String, Object>();

        try {

            if(StringUtils.isBlank(qy))
            {
                qy = "54";
            }

            List<Map<String, String>> list = combinationAnalysisService.selectPersonalBreakOnesPromise(startTime, endTime, qy);
            result.put("data", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

        }catch(Exception e){

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

        }
        return result;
    }

    @GetMapping("/selectRegionBreakOnesPromise")
    @ApiOperation(value="根据-{年月日}-查询历年区域失信统计记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="query", name = "startTime", value = "开始时间", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="query", name = "endTime", value = "结束时间", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{年份}-使用柱状图列举出要统计的区域失信数",value = "query",type = "PC")
    public Map<String, Object> selectRegionBreakOnesPromise(HttpServletRequest request , HttpServletResponse response ,@RequestParam(required = false,name = "startTime")String startTime,@RequestParam(required = false,name = "endTime")String endTime)
    {

        Map<String, Object> result = new HashMap<String, Object>();

        try {

            List<Map<String, String>> list = combinationAnalysisService.selectRegionBreakOnesPromise(startTime, endTime);
            result.put("data", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

        }catch(Exception e){

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());

        }
        return result;
    }


}
