package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.dtos.DaSysMenuDetail;
import com.philisense.www.dtos.DaUserMenu;
import com.philisense.www.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

/**
 * @author Administrator
 */
@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"creditdirectory")
@Api(tags = "CreditDirectoryControllerForWeb |一个用来操作-{信用目录}-业务模块的控制器")
public class CreditDirectoryControllerForWeb extends BaseUtilController {

    @Autowired
    private SysMenuService sysMenuService;

    @Autowired
    private UserMenuApplyService userMenuApplyService;

    @Autowired
    private UserMenuApproveService userMenuApproveService;

    @Autowired
    private SysMenuDetailService sysMenuDetailService;

    /**
     * 获取订阅申请目录
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/selectApplyDictory")
    @ApiOperation(value = "根据-{用户表和用户目录表目录表}-订阅审批目录详情", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "userName", value = "申请人姓名", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "menuName", value = "目录名称", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "sign", value = "状态", required = false,  dataTypeClass = String.class),
    })
    @OperateLog(name = "根据-{用户表和用户目录表目录表}-查询审批目录详情", value = "query", type = "PC")
    public Map<String, Object> selectApplyDictory(HttpServletRequest request, HttpServletResponse response, String userName,
                                                     String menuName,String sign) {

        Map<String, Object> result = new HashMap<String, Object>();

        try {
            List<Map<String, Object>> list = userMenuApplyService.selectApplyDictory(menuName, userName, sign);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put("list",list );
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }



    /**
     * 查询目录详情
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/selectMenuDetail")
    @ApiOperation(value = "根据-{目录id}-查询目录表详情", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "menuId", value = "目录id", required = true,  dataTypeClass = String.class),
    })
    @OperateLog(name = "根据-{目录id}-查询目录表详情", value = "query", type = "PC")
    public Map<String, Object> selectIndustryRadarChart(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, String> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        String menuId = map.get("menuId");
        try {
            DaSysMenuDetail daSysMenuDetail1 = sysMenuDetailService.queryById(menuId);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put("daSysMenuDetail", daSysMenuDetail1);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    /**
     * 查询目录详情
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/updateMenuDetail")
    @ApiOperation(value = "根据-{目录id}-编辑目录表详情", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "menuId", value = "目录id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "menuName", value = "目录名称", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "dataType", value = "数据类型", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "databaseType", value = "数据库类型", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "tableName", value = "表名称", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "remark", value = "描述", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "isDelete", value = "是否为删除", required = false,  dataTypeClass = Integer.class)
    })
    @OperateLog(name = "根据-{目录id}-查询目录表详情", value = "update", type = "PC")
    public Map<String, Object> updateMenuDetail(HttpServletRequest request, HttpServletResponse response, @RequestBody DaSysMenuDetail daSysMenuDetail) {

        Map<String, Object> result = new HashMap<String, Object>();

        try {
            DaSysMenuDetail queryData = sysMenuDetailService.queryById(daSysMenuDetail.getMenuId());
            if(queryData == null){
                DaSysMenuDetail inserData  = new DaSysMenuDetail();
                inserData.setMenuId(daSysMenuDetail.getMenuId());
                inserData.setIsDelete(0);
                sysMenuDetailService.insert(inserData);
            }
            DaSysMenuDetail updateData = sysMenuDetailService.update(daSysMenuDetail);
            result.put("daSysMenuDetail", updateData);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    /**
     * 查询目录详情
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/getTableData")
    @ApiOperation(value = "根据-{目录id}-显示数据库所有表名", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "tableName", value = "表名", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录id}-显示数据库所有表名", value = "query", type = "PC")
    public Map<String, Object> getTableData(HttpServletRequest request, HttpServletResponse response,@RequestBody Map<String, Object> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        String tableName = (String)map.get("tableName");
        tableName = "TRIBT_SERVICE." + tableName;
        try {
            List<Map<String, Object>> list = sysMenuService.getTableData(tableName);
            List<Map<String, Object>> list1 = sysMenuService.getTableColumn((String)map.get("tableName"));
            result.put("list", list);
            result.put("columns", list1);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    /**
     * 获取当前表的所有信息
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/showDatabases")
    @ApiOperation(value = "根据-{目录id}-显示数据库所有表名", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @OperateLog(name = "根据-{目录id}-显示数据库所有表名", value = "query", type = "PC")
    public Map<String, Object> showDatabases(HttpServletRequest request, HttpServletResponse response) {

        Map<String, Object> result = new HashMap<String, Object>();

        try {
            List<Map<String, Object>> list = sysMenuService.showDatabases();
            result.put("list", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    @PostMapping("/getProMenuTreeByLevelCode")
    @ApiOperation(value = "查询所有菜单数据根据层次码", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "查询所有菜单数据根据层次码", value = "query", type = "PC")
    public Map<String, Object> getProMenuTreeByLevelCode(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String parentid = map.get("parentid") + "";

            List<Map<String, Object>> treedata = sysMenuService.getProMenuTreeByLevelCode(map);

            List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

            if (null != treedata && treedata.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : treedata) {
                    tree.put("key", tree.get("id"));
                    tree.put("title", tree.get("text"));

                    if (tree.get("parentid").equals(parentid)) {
                        parenttreedata.add(tree);
                    }
                }

                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                for (Map<String, Object> ptree : parenttreedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("text"));

                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            second_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点
                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("text"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            third_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //四级树节点
                for (Map<String, Object> ptree : third_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("text"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            fourth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //五级树节点
                for (Map<String, Object> ptree : fourth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("text"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            fifth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //六级树节点
                for (Map<String, Object> ptree : fifth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("text"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            sixth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

            }

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST, parenttreedata);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    /**
     * 添加用户申请订阅目录数据
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/insertUserApplyData")
    @ApiOperation(value = "根据-{目录列表信息等}-添加用户订阅审批目录数据", notes = "成功返回:{\"success\":true,\"message\",\"数据添加成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据添加失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "createBy", value = "用户id", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "menuId", value = "目录列表", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "sign", value = "审核状态", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "reason", value = "申请理由", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录列表信息等}-添加用户订阅审批目录数据", value = "insert", type = "PC")
    @Transactional
    public Map<String, Object> insertUserApplyData(HttpServletRequest request, HttpServletResponse response, @RequestBody DaUserMenu daUserMenu) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            daUserMenu.setCreateTime(new Date());
            userMenuApplyService.insert(daUserMenu);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    /**
     * 添加用户申请订阅目录数据
     * @param request
     * @param response
     * @param
     * @return
     */
    @PostMapping("/insertUserApproveData")
    @ApiOperation(value = "根据-{目录列表信息等}-添加用户发布审批目录数据", notes = "成功返回:{\"success\":true,\"message\",\"数据添加成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据添加失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "createBy", value = "用户id", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "menuId", value = "目录列表", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "sign", value = "审核状态", required = false,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "reason", value = "申请理由", required = false,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录列表信息等}-添加用户发布审批目录数据", value = "insert", type = "PC")
    @Transactional
    public Map<String, Object> insertUserApproveData(HttpServletRequest request, HttpServletResponse response, @RequestBody DaUserMenu daUserMenu) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            daUserMenu.setCreateTime(new Date());
            userMenuApproveService.insert(daUserMenu);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }


    @PostMapping("/updateUserApplyData")
    @ApiOperation(value = "根据-{目录列表信息等}-更新用户订阅审批目录数据", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "id", value = "列表id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "sign", value = "审核状态", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录列表信息等}-更新用户订阅审批目录数据", value = "update", type = "PC")
    @Transactional
    public Map<String, Object> updateUserApplyData(HttpServletRequest request, HttpServletResponse response, @RequestBody DaUserMenu daUserMenu) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            DaUserMenu daUserMenu1 = userMenuApplyService.update(daUserMenu);
            result.put("daUserMenu", daUserMenu1);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    @PostMapping("/getMenuData")
    @ApiOperation(value = "根据-{目录列表信息等}-更新用户订阅审批目录数据", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "menuName", value = "目录名称", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录列表信息等}-更新用户订阅审批目录数据", value = "query", type = "PC")
    public Map<String, Object> getMenuData(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String menuName = (String)map.get("menuName");
            List<Map<String, Object>> list = sysMenuService.getMenuData(menuName);
            result.put("list", list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }

    @PostMapping("/cancleApprove")
    @ApiOperation(value = "根据-{目录列表信息等}-取消发布", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "menuId", value = "目录名称", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{目录列表信息等}-取消发布", value = "update", type = "PC")
    public Map<String, Object> cancleApprove(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String menuId = (String)map.get("menuId");
            sysMenuService.cancleApprove(menuId);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }

        System.out.println(result);

        return result;
    }
}
