package com.philisense.www.controller.web;

import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import cn.hutool.poi.word.WordUtil;
import com.deepoove.poi.XWPFTemplate;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.CreditIndexReport;
import com.philisense.www.service.CreditIndexReportService;
import com.philisense.www.service.EnterpriseInformationPublicityService;
import com.philisense.www.service.ExponentialAlgorithmService;
import com.philisense.www.service.LabelManageService;
import com.philisense.www.utils.EncodeUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.tuple.Pair;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.STNumberFormat;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ResourceLoader;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.nio.charset.StandardCharsets;
import java.text.DecimalFormat;
import java.util.*;
import java.util.stream.Collectors;


@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "creditindexreport")
@Api(tags = "CreditIndexReportControllerForWeb|一个用来操作-{信用指数报告}-业务模块的控制器(author:xxg)")
public class CreditIndexReportControllerForWeb extends BaseUtilController {

    @Autowired
    private CreditIndexReportService creditindexreportService;

    @Resource
    ResourceLoader resourceLoader;

    @Autowired
    private EnterpriseInformationPublicityService enterpriseInformationPublicityService;

    @Autowired
    private LabelManageService labelManageService;//标签管理

    @Autowired
    private ExponentialAlgorithmService exponentialAlgorithmService;//指数算法

    @GetMapping("/delete")
    @ApiOperation(value = "根据-{信用指数报告}-主键删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{信用指数报告}-主键删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteByPrimaryKeyForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = creditindexreportService.deleteByPrimaryKey(recordid);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @GetMapping("/get")
    @ApiOperation(value = "根据-{信用指数报告}-主键查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{信用指数报告}-主键查询记录", value = "query", type = "PC")
    public Map<String, Object> selectByPrimaryKeyForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, creditindexreportService.selectByPrimaryKey(recordid));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insert")
    @ApiOperation(value = "根据-{信用指数报告}-对象插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象插入记录", value = "insert", type = "PC")
    public Map<String, Object> insertForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

            creditindexreportService.insert(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/update")
    @ApiOperation(value = "根据-{信用指数报告}-对象更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象更新记录", value = "update", type = "PC")
    public Map<String, Object> updateForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            Map<String, Object> paramsmap = creditindexreportService.selectByPrimaryKey(map.get("id") + "");

            int flag = 0;

            if (null != paramsmap && paramsmap.size() > 0) {
                paramsmap.putAll(map);
                flag = creditindexreportService.update(paramsmap);
            }

            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteByMap")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteByMapForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = creditindexreportService.deleteByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateByMap")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map更新记录", value = "update", type = "PC")
    public Map<String, Object> updateByMapForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            int flag = creditindexreportService.updateByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getOne")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map查询记录", value = "query", type = "PC")
    public Map<String, Object> getOneForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, creditindexreportService.getOne(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getAll")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map查询所有记录", value = "query", type = "PC")
    public Map<String, Object> getAllForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            List<Map<String, Object>> treedata = creditindexreportService.getAll(map);

            List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

            if (null != treedata && treedata.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : treedata) {

                    tree.put("name", tree.get("name"));
                    tree.put("level", tree.get("level"));

                    if (tree.get("level").equals("1")) {
                        parenttreedata.add(tree);
                    }

                }

                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                for (Map<String, Object> ptree : parenttreedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {

                        tree.put("name", tree.get("name"));
                        tree.put("level", tree.get("level"));
                        tree.put("title", tree.get("title"));

                        if (tree.get("title").equals(ptree.get("name")) && tree.get("level").equals("2")) {
                            second_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                    for (Map<String, Object> tree : treedata) {

                        tree.put("name", tree.get("name"));
                        tree.put("level", tree.get("level"));
                        tree.put("title", tree.get("title"));

                        if (tree.get("title").equals(ptree.get("name")) && tree.get("level").equals("3")) {
                            third_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

            }

            result.put(DATALIST, parenttreedata);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put("begTime", map.get("begTime"));
            result.put("endTime", map.get("endTime"));
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            //result.put(DATALIST, creditindexreportService.getAll(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getAllTree")
    @ApiOperation(value = "根据-{信用指数自定义报告详情}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数自定义报告详情}-对象Map查询所有记录", value = "query", type = "PC")
    public Map<String, Object> getAllForCreditIndexReportsForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            int sxbzxrmdxxCount = labelManageService.sxbzxrmdxxCount(map);//失信被执行人名单信息
            int xzxkxxCount = labelManageService.xzxkxxCount(map);//行政许可信息
            int xzcfxxCount = labelManageService.xzcfxxCount(map);//行政处罚信息

            DecimalFormat df = new DecimalFormat("#.##");

            List<Map<String, Object>> zssfMap = exponentialAlgorithmService.selectExponentialAlgorithm(map);

            List<Object> dlmids = zssfMap.stream().map(q -> q.get("dlmid")).distinct().collect(Collectors.toList());

            List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();

            if (null != zssfMap && zssfMap.size() > 0) {

                for (int l = 0; l < dlmids.size(); l++) {

                    Map<String, Object> labelMap = new HashMap<String, Object>();

                    Double bqsz = 0D;

                    Double number = 0D;

                    String name = "";

                    labelMap.put("dlmid", dlmids.get(l));//标签id

                    for (Map<String, Object> zssf : zssfMap) {

                        if (zssf.get("dlmid").equals(dlmids.get(l))) {

                            number = Double.valueOf(zssf.get("number").toString());

                            labelMap.put("dlmparentid", zssf.get("dlmparentid"));//标签上级id
                            labelMap.put("dlmlabelname", zssf.get("dlmlabelname"));//标签名称
                            labelMap.put("name", zssf.get("dlmlabelname"));//标签名称
                            name = zssf.get("dlmlabelname").toString();
                            labelMap.put("dlmscore", zssf.get("dlmscore"));//标签权重
                            labelMap.put("dlmattribute", zssf.get("dlmattribute"));//标签属性
                            labelMap.put("dlplabelname", zssf.get("dlplabelname"));//标签上级名称
                            labelMap.put("title", zssf.get("dlplabelname"));//标签上级名称

                            labelMap.put("announce", true);

                            if (zssf.get("deaattribute").equals("失信被执行人名单信息")) {
                                bqsz = 100D - sxbzxrmdxxCount;
                            }
                            else if(zssf.get("deaattribute").equals("行政许可信息"))
                            {
                                bqsz = 100D - xzxkxxCount;
                            }
                            else if(zssf.get("deaattribute").equals("行政处罚信息"))
                            {
                                bqsz = 100D - xzcfxxCount;
                            }
                            else {
                                bqsz = (double) (1 + Math.random() * (100 - 1 + 1));//dlmattribute
                            }

                            bqsz = Double.valueOf(df.format(bqsz));//通过选择标签属性获取到对应的分数（必填项）

                            Double bqszs = 0D;

                            if (zssf.get("deaattribute").equals("0")) {
                                bqszs = Double.valueOf(zssf.get("deaattribute").toString());
                            } else {
                                bqszs = (double) (1 + Math.random() * (100 - 1 + 1));//获取多个属性分数
                            }

                            bqszs = Double.valueOf(df.format(bqszs));

                            //计算分值

                            String fh = zssf.get("deacompute").toString();

                            if (fh.equals("+")) {
                                bqsz = bqsz + bqszs;
                            }

                            if (fh.equals("-")) {
                                bqsz = bqsz - bqszs;
                            }

                            if (fh.equals("*")) {
                                bqsz = bqsz * bqszs;
                            }

                            if (fh.equals("/")) {
                                bqsz = bqsz / bqszs;
                            }

                            bqsz = Double.valueOf(df.format(bqsz));

                        }
                    }

                    number = number / 100;

                    Double fs = Double.valueOf(df.format(bqsz * number));

                    labelMap.put("score", fs);//标签权重

                    labelMap.put("bz", name + ",指标为" + fs);

                    data.add(labelMap);

                }


                List<Map<String, Object>> labeldata1 = selectLabelManageForWeb(data);

                if (null != labeldata1 && labeldata1.size() > 0) {
                    for (Map<String, Object> list : labeldata1) {
                        Map<String, Object> labelMap = new HashMap<String, Object>();
                        labelMap.put("score", list.get("score"));//标签权重
                        labelMap.put("bz", list.get("bz"));
                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                        labelMap.put("name", list.get("name"));//标签名称
                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                        labelMap.put("title", list.get("title"));//标签上级名称
                        labelMap.put("announce", false);
                        data.add(labelMap);
                    }

                    List<Map<String, Object>> labeldata2 = selectLabelManageForWeb(labeldata1);

                    if (null != labeldata2 && labeldata2.size() > 0) {
                        for (Map<String, Object> list : labeldata2) {
                            Map<String, Object> labelMap = new HashMap<String, Object>();
                            labelMap.put("score", list.get("score"));//标签权重
                            labelMap.put("bz", list.get("bz"));
                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                            labelMap.put("name", list.get("name"));//标签名称
                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                            labelMap.put("title", list.get("title"));//标签上级名称
                            labelMap.put("announce", false);
                            data.add(labelMap);
                        }

                        List<Map<String, Object>> labeldata3 = selectLabelManageForWeb(labeldata2);

                        if (null != labeldata3 && labeldata3.size() > 0) {
                            for (Map<String, Object> list : labeldata3) {
                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                labelMap.put("score", list.get("score"));//标签权重
                                labelMap.put("bz", list.get("bz"));
                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                labelMap.put("name", list.get("name"));//标签名称
                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                labelMap.put("title", list.get("title"));//标签上级名称
                                labelMap.put("announce", false);
                                data.add(labelMap);
                            }

                            List<Map<String, Object>> labeldata4 = selectLabelManageForWeb(labeldata3);

                            if (null != labeldata4 && labeldata4.size() > 0) {
                                for (Map<String, Object> list : labeldata4) {
                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                    labelMap.put("score", list.get("score"));//标签权重
                                    labelMap.put("bz", list.get("bz"));
                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                    labelMap.put("name", list.get("name"));//标签名称
                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                    labelMap.put("title", list.get("title"));//标签上级名称
                                    labelMap.put("announce", false);
                                    data.add(labelMap);
                                }

                                List<Map<String, Object>> labeldata5 = selectLabelManageForWeb(labeldata4);

                                if (null != labeldata5 && labeldata5.size() > 0) {
                                    for (Map<String, Object> list : labeldata5) {
                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                        labelMap.put("score", list.get("score"));//标签权重
                                        labelMap.put("bz", list.get("bz"));
                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                        labelMap.put("name", list.get("name"));//标签名称
                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                        labelMap.put("title", list.get("title"));//标签上级名称
                                        labelMap.put("announce", false);
                                        data.add(labelMap);
                                    }

                                    List<Map<String, Object>> labeldata6 = selectLabelManageForWeb(labeldata5);

                                    if (null != labeldata6 && labeldata6.size() > 0) {
                                        for (Map<String, Object> list : labeldata6) {
                                            Map<String, Object> labelMap = new HashMap<String, Object>();
                                            labelMap.put("score", list.get("score"));//标签权重
                                            labelMap.put("bz", list.get("bz"));
                                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                            labelMap.put("name", list.get("name"));//标签名称
                                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                            labelMap.put("title", list.get("title"));//标签上级名称
                                            labelMap.put("announce", false);
                                            data.add(labelMap);
                                        }

                                        List<Map<String, Object>> labeldata7 = selectLabelManageForWeb(labeldata6);

                                        if (null != labeldata7 && labeldata7.size() > 0) {
                                            for (Map<String, Object> list : labeldata7) {
                                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                                labelMap.put("score", list.get("score"));//标签权重
                                                labelMap.put("bz", list.get("bz"));
                                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                labelMap.put("name", list.get("name"));//标签名称
                                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                labelMap.put("title", list.get("title"));//标签上级名称
                                                labelMap.put("announce", false);
                                                data.add(labelMap);
                                            }

                                            List<Map<String, Object>> labeldata8 = selectLabelManageForWeb(labeldata7);

                                            if (null != labeldata8 && labeldata8.size() > 0) {
                                                for (Map<String, Object> list : labeldata8) {
                                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                                    labelMap.put("score", list.get("score"));//标签权重
                                                    labelMap.put("bz", list.get("bz"));
                                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                    labelMap.put("name", list.get("name"));//标签名称
                                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                    labelMap.put("title", list.get("title"));//标签上级名称
                                                    labelMap.put("announce", false);
                                                    data.add(labelMap);
                                                }

                                                List<Map<String, Object>> labeldata9 = selectLabelManageForWeb(labeldata8);

                                                if (null != labeldata9 && labeldata9.size() > 0) {
                                                    for (Map<String, Object> list : labeldata9) {
                                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                                        labelMap.put("score", list.get("score"));//标签权重
                                                        labelMap.put("bz", list.get("bz"));
                                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                        labelMap.put("name", list.get("name"));//标签名称
                                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                        labelMap.put("title", list.get("title"));//标签上级名称
                                                        labelMap.put("announce", false);
                                                        data.add(labelMap);
                                                    }

                                                    List<Map<String, Object>> labeldata10 = selectLabelManageForWeb(labeldata9);

                                                    if (null != labeldata10 && labeldata10.size() > 0) {
                                                        for (Map<String, Object> list : labeldata10) {
                                                            Map<String, Object> labelMap = new HashMap<String, Object>();
                                                            labelMap.put("score", list.get("score"));//标签权重
                                                            labelMap.put("bz", list.get("bz"));
                                                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                            labelMap.put("name", list.get("name"));//标签名称
                                                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                            labelMap.put("title", list.get("title"));//标签上级名称
                                                            labelMap.put("announce", false);
                                                            data.add(labelMap);
                                                        }
                                                    }
                                                }

                                            }
                                        }

                                    }

                                }

                            }

                        }

                    }


                }


            }


            if (data.size() > 0) {

                List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

                if (null != data && data.size() > 0) {

                    //一级树节点
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmid").equals("1")) {
                            parenttreedata.add(tree);
                        }

                    }

                    //二级树节点
                    List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                    for (Map<String, Object> ptree : parenttreedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                second_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }

                    List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点

                    //三级树节点
                    for (Map<String, Object> ptree : second_treedata) {
                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                third_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }

                    List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                    List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                    List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                    List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                    List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                    List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                    List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点


                    //四级树节点
                    for (Map<String, Object> ptree : third_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                fourth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }


                    //五级树节点
                    for (Map<String, Object> ptree : fourth_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                fifth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }


                    //六级树节点
                    for (Map<String, Object> ptree : fifth_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                sixth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }

                    //七级树节点
                    for (Map<String, Object> ptree : sixth_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                seventh_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }
                    //八级树节点
                    for (Map<String, Object> ptree : seventh_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                eighth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }

                    //九级树节点
                    for (Map<String, Object> ptree : eighth_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                nineth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }

                    //十级树节点
                    for (Map<String, Object> ptree : nineth_treedata) {

                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                tenth_treedata.add(tree);
                                sontreedata.add(tree);
                            }
                        }
                        ptree.put("children", sontreedata);
                    }


                }

                result.put(DATALIST, parenttreedata);
            }

//            result.put(DATALIST, data);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            //result.put(DATALIST, creditindexreportService.getAll(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    public List<Map<String, Object>> selectLabelManageForWeb(List<Map<String, Object>> data) {
        //根据最下级目录获取到的数据 查询上级目录进行计算

        DecimalFormat df = new DecimalFormat("#.##");

        List<Map<String, Object>> labeldata = new ArrayList<Map<String, Object>>();

        List<Object> dlmparentids = data.stream().map(q -> q.get("dlmparentid")).distinct().collect(Collectors.toList());

        for (int p = 0; p < dlmparentids.size(); p++) {
            Map<String, Object> labelMap = new HashMap<String, Object>();

            Double bqsz = 0D;//标签分值

            Double number = 0D;//权重信息

            String bjname = "";//标签名称

            if (!"0".equals(dlmparentids.get(p).toString())) {
                Map<String, Object> plabelMap = labelManageService.selectByPrimaryKey(dlmparentids.get(p).toString());
                if (plabelMap.size() > 0 && plabelMap != null) {

                    for (Map<String, Object> pmap : data) {
                        if(pmap.get("dlmparentid").equals(dlmparentids.get(p).toString()))
                        {
                            bqsz = bqsz + Double.valueOf(pmap.get("score").toString());
                            bjname = bjname + "，" + pmap.get("name");
                        }
                    }

                    number = Double.valueOf(plabelMap.get("score").toString()) / 100;

                    Double fs = Double.valueOf(df.format(bqsz * number));

                    labelMap.put("score", fs);//标签权重

                    String bz = "综合" + bjname.substring(1, bjname.length()) + "指标，" + plabelMap.get("labelName") + "评估得分为" + fs + "分";

                    labelMap.put("bz", bz.replace("顶级目录",""));

                    labelMap.put("dlmid", plabelMap.get("id"));//标签id
                    labelMap.put("dlmparentid", plabelMap.get("parentId"));//标签上级id
                    labelMap.put("dlmlabelname", plabelMap.get("labelName"));//标签名称
                    labelMap.put("name", plabelMap.get("labelName"));//标签名称
                    labelMap.put("dlmscore", plabelMap.get("score"));//标签权重
                    labelMap.put("dlmattribute", plabelMap.get("attribute"));//标签属性
                    labelMap.put("dlplabelname", plabelMap.get("parentName"));//标签上级名称
                    labelMap.put("title", plabelMap.get("parentName"));//标签上级名称

                    labeldata.add(labelMap);

                }
            }

        }

        return labeldata;
        //根据最下级目录获取到的数据 查询上级目录进行计算
    }

    @PostMapping("/queryPage")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map分页记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map分页记录", value = "query", type = "PC")
    public Map<String, Object> queryPageForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            int currentPage = map.get(DATACURRENT) != null ? Integer.parseInt(map.get(DATACURRENT) + "") - 1 : 0;
            int pageSize = map.get(PAGESIZE) != null ? Integer.parseInt(map.get(PAGESIZE) + "") : 10;
            int pageStart = currentPage * pageSize;

            map.put(PAGESIZE, pageSize);
            map.put(PAGESTART, pageStart);

            int total = creditindexreportService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if (total > 0) {
                datalist = creditindexreportService.queryPage(map);
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST, datalist);
            tempresult.put(DATATOTAL, total);
            tempresult.put(PAGESIZE, map.get(PAGESIZE) != null ? map.get(PAGESIZE) : 10);
            tempresult.put(DATACURRENT, map.get(DATACURRENT) != null ? map.get(DATACURRENT) : 0);
            result.put(DATARESULT, tempresult);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/count")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map统计查询总数记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map统计查询总数记录", value = "query", type = "PC")
    public Map<String, Object> countForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATATOTAL, creditindexreportService.count(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insertBatch")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map批量插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map批量插入记录", value = "insert", type = "PC")
    public Map<String, Object> insertBatchForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            for (Map<String, Object> map : list) {
                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
            }

            creditindexreportService.insertBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteBatch")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map批量删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map批量删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteBatchForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            creditindexreportService.deleteBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateBatch")
    @ApiOperation(value = "根据-{信用指数报告}-对象Map批量更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告}-对象Map批量更新记录", value = "update", type = "PC")
    public Map<String, Object> updateBatchForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            creditindexreportService.updateBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    @GetMapping("/export")
    @ApiOperation(value = "根据-{{信用指数报告}}-对象Map导出所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告}}-对象Map导出所有记录", value = "query", type = "PC")
    public void exportForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            List<Map<String, Object>> rows = creditindexreportService.getAll(map);
            // 通过工具类创建writer
            //创建xlsx格式的
            ExcelWriter writer = ExcelUtil.getWriter(true);
            String filename = "信用指数报告";
            getWriter(writer, filename);
            writer.setHeaderAlias(getKVAliasMap());


            writer.setOnlyAlias(true);

            // 一次性写出内容，使用默认样式，强制输出标题
            writer.write(rows, true);

            //response为HttpServletResponse对象
            response.setContentType("application/vnd.ms-excel;charset=utf-8");
            //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
            response.setHeader("Content-Disposition", "attachment;filename=" + filename + "_EnterpriseInformationPublicity.xlsx");
            ServletOutputStream out = response.getOutputStream();
            writer.flush(out, true);
            // 关闭writer，释放内存
            writer.close();
            //此处记得关闭输出Servlet流
            IoUtil.close(out);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
    }


    @GetMapping("/exportTemplate")
    @ApiOperation(value = "根据-{{信用指数报告}}-下载导出模板", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告}}-下载导出模板", value = "query", type = "PC")
    public void exportTemplateForCreditIndexReportForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String filename = "信用指数报告";
            InputStream resource = getClass().getClassLoader().getResourceAsStream("excelTemplate/creditindexreport" + "/" + filename + "_CreditinDexreport.xlsx");
            //response为HttpServletResponse对象
            response.setContentType("application/vnd.ms-excel;charset=utf-8");
            //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
            response.setHeader("Content-Disposition", "attachment;filename=" + filename + "_CreditinDexreport.xlsx");
            ServletOutputStream out = response.getOutputStream();
            IoUtil.copy(resource, out);
            //此处记得关闭输出Servlet流
            IoUtil.close(out);
            IoUtil.close(resource);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
    }


    @PostMapping("/importExcel")
    @ApiOperation(value = "根据-{{信用指数报告}}-对象Map批量导入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告}}-对象Map批量导入记录", value = "update", type = "PC")
    public Map<String, Object> importExcelForCreditIndexReportForWeb(String baseDir, MultipartFile file) {
        Map<String, Object> result = new HashMap<String, Object>();

        if (!file.isEmpty()) {
            try {
                ExcelReader reader = ExcelUtil.getReader(file.getInputStream());

                reader.setHeaderAlias(getVKAliasMap());


                List<Map<String, Object>> list = new ArrayList<>();
                List<Map<String, Object>> read = reader.read(1, 2, Integer.MAX_VALUE);

                for (Map<String, Object> map : read) {


                    if ("".equals(map.get(CreditIndexReport.ID_KEY))) {
                        map.put(CreditIndexReport.ID_KEY, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.TITLE))) {
                        map.put(CreditIndexReport.TITLE, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.NAME))) {
                        map.put(CreditIndexReport.NAME, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.TYPE))) {
                        map.put(CreditIndexReport.TYPE, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.SCORE))) {
                        map.put(CreditIndexReport.SCORE, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.REMARKS))) {
                        map.put(CreditIndexReport.REMARKS, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.XYDM))) {
                        map.put(CreditIndexReport.XYDM, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.QYMC))) {
                        map.put(CreditIndexReport.QYMC, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.BEGTIME))) {
                        map.put(CreditIndexReport.BEGTIME, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.ENDTIME))) {
                        map.put(CreditIndexReport.ENDTIME, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.SORT))) {
                        map.put(CreditIndexReport.SORT, null);
                    }

                    if ("".equals(map.get(CreditIndexReport.LEVEL))) {
                        map.put(CreditIndexReport.LEVEL, null);
                    }

                    list.add(map);

                }
                creditindexreportService.insertBatch(list);

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG);
        return result;
    }


    protected void getWriter(ExcelWriter writer, String filename) {
        // 通过工具类创建writer
        //创建xlsx格式的
        writer.setColumnWidth(0, 25);
        writer.setColumnWidth(1, 25);
        writer.setColumnWidth(2, 25);
        writer.setColumnWidth(3, 25);
        writer.setColumnWidth(4, 25);
        writer.setColumnWidth(5, 25);
        writer.setColumnWidth(6, 25);
        writer.setColumnWidth(7, 25);
        writer.setColumnWidth(8, 25);
        writer.setColumnWidth(9, 25);
        writer.setColumnWidth(10, 25);
        writer.setColumnWidth(11, 25);
        writer.setColumnWidth(12, 25);
        // 合并单元格后的标题行，使用默认标题样式
        writer.merge(12, filename);

    }


    protected Map<String, String> getKVAliasMap() {

        Map<String, String> aliasMap = new LinkedHashMap<>();

        aliasMap.put(CreditIndexReport.ID_KEY, "主键 ");
        aliasMap.put(CreditIndexReport.TITLE, "标题 ");
        aliasMap.put(CreditIndexReport.NAME, "名称  ");
        aliasMap.put(CreditIndexReport.TYPE, "类型  ");
        aliasMap.put(CreditIndexReport.SCORE, "分数  ");
        aliasMap.put(CreditIndexReport.REMARKS, "备注 ");
        aliasMap.put(CreditIndexReport.XYDM, "统一社会信用代码 ");
        aliasMap.put(CreditIndexReport.QYMC, "企业（机构）名称  ");
        aliasMap.put(CreditIndexReport.BEGTIME, "开始日期  ");
        aliasMap.put(CreditIndexReport.ENDTIME, "结束日期  ");
        aliasMap.put(CreditIndexReport.SORT, "排序 ");
        aliasMap.put(CreditIndexReport.LEVEL, "级别 ");
        return aliasMap;

    }

    protected Map<String, String> getVKAliasMap() {
        Map<String, String> aliasMap = new LinkedHashMap<>();

        aliasMap.put("主键 ", CreditIndexReport.ID_KEY);
        aliasMap.put("标题 ", CreditIndexReport.TITLE);
        aliasMap.put("名称  ", CreditIndexReport.NAME);
        aliasMap.put("类型 ", CreditIndexReport.TYPE);
        aliasMap.put("分数 ", CreditIndexReport.SCORE);
        aliasMap.put("备注 ", CreditIndexReport.REMARKS);
        aliasMap.put("统一社会信用代码 ", CreditIndexReport.XYDM);
        aliasMap.put("企业（机构）名称  ", CreditIndexReport.QYMC);
        aliasMap.put("开始日期 ", CreditIndexReport.BEGTIME);
        aliasMap.put("结束日期 ", CreditIndexReport.ENDTIME);
        aliasMap.put("排序 ", CreditIndexReport.SORT);
        aliasMap.put("级别 ", CreditIndexReport.LEVEL);
        return aliasMap;
    }

    //导出word
    @GetMapping("/installCreditindexreportForWord")
    @ApiOperation(value = "根据统一信用代码下载信用指数报告", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据统一信用代码下载信用指数报告", value = "query", type = "PC")
    public void installCreditindexreportForWord(HttpServletRequest request, HttpServletResponse response, @RequestParam String begTime, @RequestParam String endTime, @RequestParam String xydm) {
        Map<String, Object> result = new HashMap<String, Object>();

        if (StringUtils.isBlank(begTime)) {
            begTime = "2022-01";
        }
        if (StringUtils.isBlank(endTime)) {
            endTime = "2022-12";
        }
        if (StringUtils.isBlank(xydm)) {
            xydm = "915400916868219536";
        }

        if (StringUtils.isNotBlank(endTime) && StringUtils.isNotBlank(begTime) && StringUtils.isNotBlank(xydm)) {
            Map<String, Object> map = new HashMap<String, Object>();
            Map<String, Object> datas = new HashMap<>();
            if (StringUtils.isNotBlank(xydm)) {
                map.put("xydm", xydm);
            }

            List<Map<String, Object>> qyxx = enterpriseInformationPublicityService.selectQyxxQuery(map);

            datas.put("ztsfdm", qyxx.get(0).get("ztsfdm"));
            datas.put("tyshxydm", qyxx.get(0).get("xydm"));
            datas.put("qymc", qyxx.get(0).get("qymc"));
            datas.put("zch", qyxx.get(0).get("zch"));
            datas.put("scztlx", qyxx.get(0).get("chness"));
            datas.put("hyml", qyxx.get(0).get("hymh"));
            datas.put("clrq", qyxx.get(0).get("clrq"));
            datas.put("djjg", qyxx.get(0).get("djjgs"));
            datas.put("ywfw", qyxx.get(0).get("ywfwlxs"));
            datas.put("jyfw", qyxx.get(0).get("jyfw"));
            datas.put("jyqx1", qyxx.get(0).get("jyrq"));
            datas.put("jyqx2", qyxx.get(0).get("jyqx"));
            datas.put("djzt", qyxx.get(0).get("djzts"));
            datas.put("qy", qyxx.get(0).get("qy"));
            datas.put("zs", qyxx.get(0).get("zs"));
            datas.put("zczb", qyxx.get(0).get("zczb"));
            datas.put("fddbr", qyxx.get(0).get("fddbr"));
            datas.put("hzrq",  qyxx.get(0).get("hzrq"));

            map.put("begTime", begTime);
            map.put("endTime", endTime);

            List<Map<String, Object>> xyzs = creditindexreportService.getAll(map);

            try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);


                int index = 1;
                for (int i = 0; i < xyzs.size(); i++) {
                    datas.put("a" + index, xyzs.get(i).get("score"));
                    index++;
                }

                //XWPFTemplate template = XWPFTemplate.compile(resourceLoader.getResource("classpath:wordTemplate/creditindexreport/creditindexreport.docx").getFile()).render(datas);
                XWPFTemplate template = XWPFTemplate.compile(WordUtil.class.getClassLoader().getResourceAsStream("wordTemplate/creditindexreport/creditindexreport.docx")).render(datas);
                //中文文件名编码处理
                String filename = qyxx.get(0).get("qymc")+"信用指数报告.docx";
                String encode = EncodeUtils.getEncoding(filename);
                if (StringUtils.isNotBlank(encode) && !"ISO-8859-1".equals(encode)) {//匹配到编码
                    filename = new String(filename.getBytes(encode), StandardCharsets.ISO_8859_1);
                }
                //response为HttpServletResponse对象
                response.setContentType("application/octet-stream");
                response.setCharacterEncoding("utf-8");
                //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                response.setHeader("Content-Disposition", "attachment;filename=" + filename);
                ServletOutputStream out = response.getOutputStream();
                template.write(out);
                out.flush();
                //此处记得关闭输出Servlet流
                IoUtil.close(out);
                // 关闭xwpfTemplate，释放内存
                template.close();


            } catch (Exception e) {
                e.printStackTrace();
            }
        }


    }

    //导出word
    @GetMapping("/installTreeDexreportForWord")
    @ApiOperation(value = "根据统一信用代码下载自定义信用指数报告", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据统一信用代码下载自定义信用指数报告", value = "query", type = "PC")
    public void installTreeDexreportForWord(HttpServletRequest request, HttpServletResponse response, @RequestParam String begTime, @RequestParam String endTime, @RequestParam String xydm) {
        Map<String, Object> result = new HashMap<String, Object>();

        if (StringUtils.isBlank(begTime)) {
            begTime = "2022-01";
        }
        if (StringUtils.isBlank(endTime)) {
            endTime = "2022-12";
        }
        if (StringUtils.isBlank(xydm)) {
            xydm = "915400916868219536";
        }

        if (StringUtils.isNotBlank(endTime) && StringUtils.isNotBlank(begTime) && StringUtils.isNotBlank(xydm)) {
            Map<String, Object> map = new HashMap<String, Object>();
            Map<String, Object> datas = new HashMap<>();
            if (StringUtils.isNotBlank(xydm)) {
                map.put("xydm", xydm);
            }

            List<Map<String, Object>> qyxx = enterpriseInformationPublicityService.selectQyxxQuery(map);

            datas.put("ztsfdm", qyxx.get(0).get("ztsfdm"));
            datas.put("tyshxydm", qyxx.get(0).get("xydm"));
            datas.put("qymc", qyxx.get(0).get("qymc"));
            datas.put("zch", qyxx.get(0).get("zch"));
            datas.put("scztlx", qyxx.get(0).get("chness"));
            datas.put("hyml", qyxx.get(0).get("hymh"));
            datas.put("clrq", qyxx.get(0).get("clrq"));
            datas.put("djjg", qyxx.get(0).get("djjgs"));
            datas.put("ywfw", qyxx.get(0).get("ywfwlxs"));
            datas.put("jyfw", qyxx.get(0).get("jyfw"));
            datas.put("jyqx1", qyxx.get(0).get("jyrq"));
            datas.put("jyqx2", qyxx.get(0).get("jyqx"));
            datas.put("djzt", qyxx.get(0).get("djzts"));
            datas.put("qy", qyxx.get(0).get("qy"));
            datas.put("zs", qyxx.get(0).get("zs"));
            datas.put("zczb", qyxx.get(0).get("zczb"));
            datas.put("fddbr", qyxx.get(0).get("fddbr"));
            datas.put("hzrq",  qyxx.get(0).get("hzrq"));

            datas.put("begTime",  begTime);
            datas.put("endTime",  endTime);

            map.put("begTime", begTime);
            map.put("endTime", endTime);

            try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                int sxbzxrmdxxCount = labelManageService.sxbzxrmdxxCount(map);//失信被执行人名单信息
                int xzxkxxCount = labelManageService.xzxkxxCount(map);//行政许可信息
                int xzcfxxCount = labelManageService.xzcfxxCount(map);//行政处罚信息

                DecimalFormat df = new DecimalFormat("#.##");

                List<Map<String, Object>> zssfMap = exponentialAlgorithmService.selectExponentialAlgorithm(map);

                List<Object> dlmids = zssfMap.stream().map(q -> q.get("dlmid")).distinct().collect(Collectors.toList());

                List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();

                if (null != zssfMap && zssfMap.size() > 0) {

                    for (int l = 0; l < dlmids.size(); l++) {

                        Map<String, Object> labelMap = new HashMap<String, Object>();

                        Double bqsz = 0D;

                        Double number = 0D;

                        String name = "";

                        labelMap.put("dlmid", dlmids.get(l));//标签id

                        for (Map<String, Object> zssf : zssfMap) {

                            if (zssf.get("dlmid").equals(dlmids.get(l))) {

                                number = Double.valueOf(zssf.get("number").toString());

                                labelMap.put("dlmparentid", zssf.get("dlmparentid"));//标签上级id
                                //labelMap.put("dlmlabelname", zssf.get("dlmlabelname"));//标签名称
                                labelMap.put("name", zssf.get("dlmlabelname"));//标签名称
                                name = zssf.get("dlmlabelname").toString();
                                labelMap.put("dlmscore", zssf.get("dlmscore"));//标签权重
                                labelMap.put("dlmattribute", zssf.get("dlmattribute"));//标签属性
                                labelMap.put("dlplabelname", zssf.get("dlplabelname"));//标签上级名称
                                labelMap.put("title", zssf.get("dlplabelname"));//标签上级名称
                                labelMap.put("announce", 1);

                                if (zssf.get("deaattribute").equals("失信被执行人名单信息")) {
                                    bqsz = 100D - sxbzxrmdxxCount;
                                }
                                else if(zssf.get("deaattribute").equals("行政许可信息"))
                                {
                                    bqsz = 100D - xzxkxxCount;
                                }
                                else if(zssf.get("deaattribute").equals("行政处罚信息"))
                                {
                                    bqsz = 100D - xzcfxxCount;
                                }
                                else {
                                    bqsz = (double) (1 + Math.random() * (100 - 1 + 1));//dlmattribute
                                }

                                bqsz = Double.valueOf(df.format(bqsz));//通过选择标签属性获取到对应的分数（必填项）


                                Double bqszs = 0D;

                                if (zssf.get("deaattribute").equals("0")) {
                                    bqszs = Double.valueOf(zssf.get("deaattribute").toString());
                                } else {
                                    bqszs = (double) (1 + Math.random() * (100 - 1 + 1));//获取多个属性分数
                                }

                                bqszs = Double.valueOf(df.format(bqszs));

                                //计算分值

                                String fh = zssf.get("deacompute").toString();

                                if (fh.equals("+")) {
                                    bqsz = bqsz + bqszs;
                                }

                                if (fh.equals("-")) {
                                    bqsz = bqsz - bqszs;
                                }

                                if (fh.equals("*")) {
                                    bqsz = bqsz * bqszs;
                                }

                                if (fh.equals("/")) {
                                    bqsz = bqsz / bqszs;
                                }

                                bqsz = Double.valueOf(df.format(bqsz));

                            }
                        }

                        number = number / 100;

                        Double fs = Double.valueOf(df.format(bqsz * number));

                        labelMap.put("score", fs);//标签权重

                        labelMap.put("dlmlabelname", name + "，指标为" + fs);

                        labelMap.put("bz", "");

                        data.add(labelMap);

                    }


                    List<Map<String, Object>> labeldata1 = selectLabelManageForWeb(data);

                    if (null != labeldata1 && labeldata1.size() > 0) {
                        for (Map<String, Object> list : labeldata1) {
                            Map<String, Object> labelMap = new HashMap<String, Object>();
                            labelMap.put("score", list.get("score"));//标签权重
                            labelMap.put("bz", list.get("bz"));
                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                            labelMap.put("name", list.get("name"));//标签名称
                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                            labelMap.put("title", list.get("title"));//标签上级名称
                            labelMap.put("announce", "0");
                            data.add(labelMap);
                        }

                        List<Map<String, Object>> labeldata2 = selectLabelManageForWeb(labeldata1);

                        if (null != labeldata2 && labeldata2.size() > 0) {
                            for (Map<String, Object> list : labeldata2) {
                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                labelMap.put("score", list.get("score"));//标签权重
                                labelMap.put("bz", list.get("bz"));
                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                labelMap.put("name", list.get("name"));//标签名称
                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                labelMap.put("title", list.get("title"));//标签上级名称
                                labelMap.put("announce", "0");
                                data.add(labelMap);
                            }

                            List<Map<String, Object>> labeldata3 = selectLabelManageForWeb(labeldata2);

                            if (null != labeldata3 && labeldata3.size() > 0) {
                                for (Map<String, Object> list : labeldata3) {
                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                    labelMap.put("score", list.get("score"));//标签权重
                                    labelMap.put("bz", list.get("bz"));
                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                    labelMap.put("name", list.get("name"));//标签名称
                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                    labelMap.put("title", list.get("title"));//标签上级名称
                                    labelMap.put("announce", "0");
                                    data.add(labelMap);
                                }

                                List<Map<String, Object>> labeldata4 = selectLabelManageForWeb(labeldata3);

                                if (null != labeldata4 && labeldata4.size() > 0) {
                                    for (Map<String, Object> list : labeldata4) {
                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                        labelMap.put("score", list.get("score"));//标签权重
                                        labelMap.put("bz", list.get("bz"));
                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                        labelMap.put("name", list.get("name"));//标签名称
                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                        labelMap.put("title", list.get("title"));//标签上级名称
                                        labelMap.put("announce", "0");
                                        data.add(labelMap);
                                    }

                                    List<Map<String, Object>> labeldata5 = selectLabelManageForWeb(labeldata4);

                                    if (null != labeldata5 && labeldata5.size() > 0) {
                                        for (Map<String, Object> list : labeldata5) {
                                            Map<String, Object> labelMap = new HashMap<String, Object>();
                                            labelMap.put("score", list.get("score"));//标签权重
                                            labelMap.put("bz", list.get("bz"));
                                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                            labelMap.put("name", list.get("name"));//标签名称
                                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                            labelMap.put("title", list.get("title"));//标签上级名称
                                            labelMap.put("announce", "0");
                                            data.add(labelMap);
                                        }

                                        List<Map<String, Object>> labeldata6 = selectLabelManageForWeb(labeldata5);

                                        if (null != labeldata6 && labeldata6.size() > 0) {
                                            for (Map<String, Object> list : labeldata6) {
                                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                                labelMap.put("score", list.get("score"));//标签权重
                                                labelMap.put("bz", list.get("bz"));
                                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                labelMap.put("name", list.get("name"));//标签名称
                                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                labelMap.put("title", list.get("title"));//标签上级名称
                                                labelMap.put("announce", "0");
                                                data.add(labelMap);
                                            }

                                            List<Map<String, Object>> labeldata7 = selectLabelManageForWeb(labeldata6);

                                            if (null != labeldata7 && labeldata7.size() > 0) {
                                                for (Map<String, Object> list : labeldata7) {
                                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                                    labelMap.put("score", list.get("score"));//标签权重
                                                    labelMap.put("bz", list.get("bz"));
                                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                    labelMap.put("name", list.get("name"));//标签名称
                                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                    labelMap.put("title", list.get("title"));//标签上级名称
                                                    labelMap.put("announce", "0");
                                                    data.add(labelMap);
                                                }

                                                List<Map<String, Object>> labeldata8 = selectLabelManageForWeb(labeldata7);

                                                if (null != labeldata8 && labeldata8.size() > 0) {
                                                    for (Map<String, Object> list : labeldata8) {
                                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                                        labelMap.put("score", list.get("score"));//标签权重
                                                        labelMap.put("bz", list.get("bz"));
                                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                        labelMap.put("name", list.get("name"));//标签名称
                                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                        labelMap.put("title", list.get("title"));//标签上级名称
                                                        labelMap.put("announce", "0");
                                                        data.add(labelMap);
                                                    }

                                                    List<Map<String, Object>> labeldata9 = selectLabelManageForWeb(labeldata8);

                                                    if (null != labeldata9 && labeldata9.size() > 0) {
                                                        for (Map<String, Object> list : labeldata9) {
                                                            Map<String, Object> labelMap = new HashMap<String, Object>();
                                                            labelMap.put("score", list.get("score"));//标签权重
                                                            labelMap.put("bz", list.get("bz"));
                                                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                            labelMap.put("name", list.get("name"));//标签名称
                                                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                            labelMap.put("title", list.get("title"));//标签上级名称
                                                            labelMap.put("announce", "0");
                                                            data.add(labelMap);
                                                        }

                                                        List<Map<String, Object>> labeldata10 = selectLabelManageForWeb(labeldata9);

                                                        if (null != labeldata10 && labeldata10.size() > 0) {
                                                            for (Map<String, Object> list : labeldata10) {
                                                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                                                labelMap.put("score", list.get("score"));//标签权重
                                                                labelMap.put("bz", list.get("bz"));
                                                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                                labelMap.put("name", list.get("name"));//标签名称
                                                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                                labelMap.put("title", list.get("title"));//标签上级名称
                                                                labelMap.put("announce", "0");
                                                                data.add(labelMap);
                                                            }
                                                        }
                                                    }

                                                }
                                            }

                                        }

                                    }

                                }

                            }

                        }


                    }


                }

                if (data.size() > 0) {

                    List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

                    if (null != data && data.size() > 0) {

                        //一级树节点
                        for (Map<String, Object> tree : data) {
                            tree.put("id", tree.get("dlmid"));
                            tree.put("parentid", tree.get("dlmparentid"));
                            if (tree.get("dlmid").equals("1")) {
                                parenttreedata.add(tree);
                            }

                        }

                        //二级树节点
                        List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                        for (Map<String, Object> ptree : parenttreedata) {
                            Integer xh = 1;
                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    tree.put("xh", xh+"、");
                                    second_treedata.add(tree);
                                    sontreedata.add(tree);
                                    xh++;
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点

                        //三级树节点
                        for (Map<String, Object> ptree : second_treedata) {
                            Integer xh = 1;
                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    tree.put("xh", "("+xh+") ");
                                    third_treedata.add(tree);
                                    sontreedata.add(tree);
                                    xh++;
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                        List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                        List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                        List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                        List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                        List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                        List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点


                        //四级树节点
                        for (Map<String, Object> ptree : third_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    fourth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }


                        //五级树节点
                        for (Map<String, Object> ptree : fourth_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    fifth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }


                        //六级树节点
                        for (Map<String, Object> ptree : fifth_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    sixth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        //七级树节点
                        for (Map<String, Object> ptree : sixth_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    seventh_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }
                        //八级树节点
                        for (Map<String, Object> ptree : seventh_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    eighth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        //九级树节点
                        for (Map<String, Object> ptree : eighth_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    nineth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        //十级树节点
                        for (Map<String, Object> ptree : nineth_treedata) {

                            List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                            for (Map<String, Object> tree : data) {
                                tree.put("id", tree.get("dlmid"));
                                tree.put("parentid", tree.get("dlmparentid"));
                                if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                                    tenth_treedata.add(tree);
                                    sontreedata.add(tree);
                                }
                            }
                            ptree.put("children", sontreedata);
                        }

                        datas.put("dataTree", parenttreedata);
                    }

                }


                //XWPFTemplate template = XWPFTemplate.compile(resourceLoader.getResource("classpath:wordTemplate/creditindexreport/treedexreport.docx").getFile()).render(datas);
                XWPFTemplate template = XWPFTemplate.compile(WordUtil.class.getClassLoader().getResourceAsStream("wordTemplate/creditindexreport/treedexreport.docx")).render(datas);
                //中文文件名编码处理
                String filename = qyxx.get(0).get("qymc")+"信用指数报告.docx";
                String encode = EncodeUtils.getEncoding(filename);
                if (StringUtils.isNotBlank(encode) && !"ISO-8859-1".equals(encode)) {//匹配到编码
                    filename = new String(filename.getBytes(encode), StandardCharsets.ISO_8859_1);
                }
                //response为HttpServletResponse对象
                response.setContentType("application/octet-stream");
                response.setCharacterEncoding("utf-8");
                //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                response.setHeader("Content-Disposition", "attachment;filename=" + filename);
                ServletOutputStream out = response.getOutputStream();
                template.write(out);
                out.flush();
                //此处记得关闭输出Servlet流
                IoUtil.close(out);
                // 关闭xwpfTemplate，释放内存
                template.close();


            } catch (Exception e) {
                e.printStackTrace();
            }
        }


    }

}
