package com.philisense.www.controller.web;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.CreditResourceDirectoryService;
import com.philisense.www.pojos.entity.CreditResourceDirectory;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import java.math.BigDecimal;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"creditresourcedirectory")
@Api(tags = "CreditResourceDirectoryControllerForWeb|一个用来操作-{信用资源目录表}-业务模块的控制器")
public class CreditResourceDirectoryControllerForWeb extends BaseUtilController{

        @Autowired
        private CreditResourceDirectoryService creditResourceDirectoryService;


        @PostMapping("/getProDeptTreeByParentid")
        @ApiOperation(value = "查询所有部门数据根据父节点id", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType = "body", name = "parentid", value = "父部门ID", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "查询所有部门数据根据父节点id", value = "query", type = "PC")
        public Map<String, Object> getProDeptTreeByParentidForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        List<Map<String, Object>> treedata = creditResourceDirectoryService.getProDeptTreeByParentid(map);

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, treedata);


                } catch (Exception e) {
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
                }
                return result;
        }


        @PostMapping("/getProDeptTreeByLevelCode")
        @ApiOperation(value = "查询所有部门数据根据层次码", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType = "body", name = "parentid", value = "父部门ID", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "查询所有部门数据根据层次码", value = "query", type = "PC")
        public Map<String, Object> getProDeptTreeByLevelCodeForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        String parentid = map.get("parentid") + "";

                        List<Map<String, Object>> treedata = creditResourceDirectoryService.getProDeptTreeByLevelCode(map);

                        List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

                        if (null != treedata && treedata.size() > 0) {

                                //一级树节点
                                for (Map<String, Object> tree : treedata) {
                                        tree.put("key", tree.get("dept_code"));

                                        if (tree.get("parentid").equals(parentid)) {
                                                parenttreedata.add(tree);
                                        }
                                }


                                //二级树节点
                                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                                for (Map<String, Object> ptree : parenttreedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));
                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        second_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }


                                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点
                                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                                List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                                List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                                List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                                List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点

                                //三级树节点
                                for (Map<String, Object> ptree : second_treedata) {
                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));
                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        third_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }


                                //四级树节点
                                for (Map<String, Object> ptree : third_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));
                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        fourth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }


                                //五级树节点
                                for (Map<String, Object> ptree : fourth_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));
                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        fifth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }


                                //六级树节点
                                for (Map<String, Object> ptree : fifth_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));
                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        sixth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }

                                //七级树节点
                                for (Map<String, Object> ptree : sixth_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));

                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        seventh_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }
                                //八级树节点
                                for (Map<String, Object> ptree : seventh_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));

                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        eighth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }

                                //九级树节点
                                for (Map<String, Object> ptree : eighth_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));

                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        nineth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }

                                //十级树节点
                                for (Map<String, Object> ptree : nineth_treedata) {

                                        List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                                        for (Map<String, Object> tree : treedata) {
                                                tree.put("key", tree.get("dept_code"));

                                                if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                                                        tenth_treedata.add(tree);
                                                        sontreedata.add(tree);
                                                }
                                        }
                                        ptree.put("children", sontreedata);
                                }


                        }

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, parenttreedata);


                } catch (Exception e) {

                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
                }
                return result;
        }


        //信用资源目录表 -》选择列表（多选）-》显示部门信息-》保存
        @GetMapping("/selectDeptList")
        @ApiOperation(value="根据-{信用资源目录表显示部门信息}-信用信息联合查询", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "parentid", value = "父部门Id", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{信用资源目录表显示部门信息}-查看部门信息",value = "query",type = "PC")
        public Map<String, Object> selectDeptList(HttpServletRequest request , HttpServletResponse response ,@RequestParam("parentid") String parentid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        List<Map<String, String>> list0 = creditResourceDirectoryService.selectDeptList(parentid);
                        result.put("dept", list0);//部门信息
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/delete")
        @ApiOperation(value="根据-{信用资源目录表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{信用资源目录表}-主键删除记录",value = "delete",type = "PC")
        public Map<String, Object> deleteByPrimaryKeyForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = creditResourceDirectoryService.deleteByPrimaryKey(recordid);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{信用资源目录表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{信用资源目录表}-主键查询记录",value = "query",type = "PC")
        public Map<String, Object> selectByPrimaryKeyForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, creditResourceDirectoryService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{信用资源目录表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                        creditResourceDirectoryService.insert(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{信用资源目录表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "ids", value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        String[] ids = map.get("ids").toString().split(",");

                        for(int i=0;i<ids.length;i++)
                        {
                                Map<String, Object> paramsmap = creditResourceDirectoryService.selectByPrimaryKey(ids[i]);

                                int flag = 0;

                                if( null!=paramsmap &&paramsmap.size()>0) {
                                        paramsmap.putAll(map);
                                        flag = creditResourceDirectoryService.update(paramsmap);
                                }

                                if(1<=flag){
                                        result.put(DATASUCCESS, SUCCESSFLAG);
                                        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                                }else{
                                        result.put(DATASUCCESS, ERRORFLAG);
                                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                                }
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteByMapForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = creditResourceDirectoryService.deleteByMap(map);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateByMapForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        int flag = creditResourceDirectoryService.updateByMap(map);
                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map查询记录",value = "query",type = "PC")
        public Map<String, Object>  getOneForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, creditResourceDirectoryService.getOne(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map查询所有记录",value = "query",type = "PC")
        public Map<String, Object>  getAllForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, creditResourceDirectoryService.getAll(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = creditResourceDirectoryService.count(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = creditResourceDirectoryService.queryPage(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map统计查询总数记录",value = "query",type = "PC")
        public Map<String, Object>  countForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATATOTAL, creditResourceDirectoryService.count(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertBatchForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        for(Map<String, Object> map:list){
                                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                        }

                        creditResourceDirectoryService.insertBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteBatchForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        creditResourceDirectoryService.deleteBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{信用资源目录表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用资源目录表}-对象Map批量更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateBatchForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        creditResourceDirectoryService.updateBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }





        @GetMapping( "/export")
        @ApiOperation(value="根据-{{信用资源目录表}}-对象Map导出所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{{信用资源目录表}}-对象Map导出所有记录",value = "query",type = "PC")
        public void exportForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        List<Map<String, Object>> rows = creditResourceDirectoryService.getAll(map);
                        // 通过工具类创建writer
                        //创建xlsx格式的
                        ExcelWriter writer = ExcelUtil.getWriter(true);
                        String filename = "信用资源目录表";
                        getWriter(writer,filename);
                        writer.setHeaderAlias(getKVAliasMap());


                        writer.setOnlyAlias(true);

                        // 一次性写出内容，使用默认样式，强制输出标题
                        writer.write(rows, true);

                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_CreditResourceDirectory.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        writer.flush(out, true);
                        // 关闭writer，释放内存
                        writer.close();
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



        @GetMapping( "/exportTemplate")
        @ApiOperation(value="根据-{{信用资源目录表}}-下载导出模板", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{{信用资源目录表}}-下载导出模板",value = "query",type = "PC")
        public void exportTemplateForCreditResourceDirectoryForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        String filename = "信用资源目录表";
                        InputStream resource = getClass().getClassLoader().getResourceAsStream("excelTemplate/creditresourcedirectory" + "/"+filename+"_CreditResourceDirectory.xlsx");
                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_CreditResourceDirectory.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        IoUtil.copy(resource,out);
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);
                        IoUtil.close(resource);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



        @PostMapping( "/importExcel")
        @ApiOperation(value="根据-{{信用资源目录表}}-对象Map批量导入记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MEMBERUNITID_KEY, value = "单位id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDIRNAME_KEY, value = "目录名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DATAITEM_KEY, value = "数据项 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DIRTYPEID_KEY, value = "目录类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERMID_KEY, value = "共享权限 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.MAINTYPEID_KEY, value = "主题类别  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREATEUSER_KEY, value = "创建人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPARTMENTID_KEY, value = "责任科室 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.FUNCTIONS_KEY, value = "职能  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.CREDITINFORECORD_KEY, value = "目录名称(信用信息记录)  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.ATTRIBUTEID_KEY, value = "属性id  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PURVIEWID_KEY, value = "权限id ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.PUBLISHSTATE_KEY, value = "发布状态  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TABLENAME_KEY, value = "表名 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.SHAREPERM_KEY, value = "公开范围  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DETAILCOLUMN_KEY, value = "显示详情 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.TIMECOLUMN_KEY, value = "记录入库时间的字段  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTID_KEY, value = "部门ID  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = CreditResourceDirectory.DEPTNAME_KEY, value = "部门名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{{信用资源目录表}}-对象Map批量导入记录",value = "update",type = "PC")
        public Map<String, Object>  importExcelForCreditResourceDirectoryForWeb(String baseDir, MultipartFile file) {
                Map<String, Object> result = new HashMap<String, Object>();

                if (!file.isEmpty()) {
                        try {
                                ExcelReader reader = ExcelUtil.getReader(file.getInputStream());

                                reader.setHeaderAlias(getVKAliasMap());


                                List<Map<String, Object>> list = new ArrayList<>();
                                List<Map<String, Object>> read = reader.read(1, 2, Integer.MAX_VALUE);

                                for (Map<String,Object> map:read){


                                        if ("".equals(map.get(CreditResourceDirectory.ID_KEY))){
                                                map.put(CreditResourceDirectory.ID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.MEMBERUNITID_KEY))){
                                                map.put(CreditResourceDirectory.MEMBERUNITID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.CREDIRNAME_KEY))){
                                                map.put(CreditResourceDirectory.CREDIRNAME_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.DATAITEM_KEY))){
                                                map.put(CreditResourceDirectory.DATAITEM_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.DIRTYPEID_KEY))){
                                                map.put(CreditResourceDirectory.DIRTYPEID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.SHAREPERMID_KEY))){
                                                map.put(CreditResourceDirectory.SHAREPERMID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.MAINTYPEID_KEY))){
                                                map.put(CreditResourceDirectory.MAINTYPEID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.CREATETIME_KEY))){
                                                map.put(CreditResourceDirectory.CREATETIME_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.CREATEUSER_KEY))){
                                                map.put(CreditResourceDirectory.CREATEUSER_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.DEPARTMENTID_KEY))){
                                                map.put(CreditResourceDirectory.DEPARTMENTID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.FUNCTIONS_KEY))){
                                                map.put(CreditResourceDirectory.FUNCTIONS_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.CREDITINFORECORD_KEY))){
                                                map.put(CreditResourceDirectory.CREDITINFORECORD_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.ATTRIBUTEID_KEY))){
                                                map.put(CreditResourceDirectory.ATTRIBUTEID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.PURVIEWID_KEY))){
                                                map.put(CreditResourceDirectory.PURVIEWID_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.PUBLISHSTATE_KEY))){
                                                map.put(CreditResourceDirectory.PUBLISHSTATE_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.TABLENAME_KEY))){
                                                map.put(CreditResourceDirectory.TABLENAME_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.SHAREPERM_KEY))){
                                                map.put(CreditResourceDirectory.SHAREPERM_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.DETAILCOLUMN_KEY))){
                                                map.put(CreditResourceDirectory.DETAILCOLUMN_KEY,null);
                                        }

                                        if ("".equals(map.get(CreditResourceDirectory.TIMECOLUMN_KEY))){
                                                map.put(CreditResourceDirectory.TIMECOLUMN_KEY,null);
                                        }


                                        list.add(map);

                                }
                                creditResourceDirectoryService.insertBatch(list);

                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                        } catch (FileNotFoundException e) {
                                e.printStackTrace();
                        } catch (IOException e) {
                                e.printStackTrace();
                        }
                }
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG);
                return result;
        }



        protected void getWriter(ExcelWriter writer,String filename){
                // 通过工具类创建writer
                //创建xlsx格式的
                writer.setColumnWidth(0,25);
                writer.setColumnWidth(1,25);
                writer.setColumnWidth(2,25);
                writer.setColumnWidth(3,25);
                writer.setColumnWidth(4,25);
                writer.setColumnWidth(5,25);
                writer.setColumnWidth(6,25);
                writer.setColumnWidth(7,25);
                writer.setColumnWidth(8,25);
                writer.setColumnWidth(9,25);
                writer.setColumnWidth(10,25);
                writer.setColumnWidth(11,25);
                writer.setColumnWidth(12,25);
                writer.setColumnWidth(13,25);
                writer.setColumnWidth(14,25);
                writer.setColumnWidth(15,25);
                writer.setColumnWidth(16,25);
                writer.setColumnWidth(17,25);
                writer.setColumnWidth(18,25);
                // 合并单元格后的标题行，使用默认标题样式
                writer.merge(18, filename);

        }



        protected Map<String,String> getKVAliasMap(){

                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put(CreditResourceDirectory.ID_KEY, "主键 ");
                aliasMap.put(CreditResourceDirectory.MEMBERUNITID_KEY, "单位id ");
                aliasMap.put(CreditResourceDirectory.CREDIRNAME_KEY, "目录名称  ");
                aliasMap.put(CreditResourceDirectory.DATAITEM_KEY, "数据项 ");
                aliasMap.put(CreditResourceDirectory.DIRTYPEID_KEY, "目录类别  ");
                aliasMap.put(CreditResourceDirectory.SHAREPERMID_KEY, "共享权限 ");
                aliasMap.put(CreditResourceDirectory.MAINTYPEID_KEY, "主题类别  ");
                aliasMap.put(CreditResourceDirectory.CREATETIME_KEY, "创建时间  ");
                aliasMap.put(CreditResourceDirectory.CREATEUSER_KEY, "创建人  ");
                aliasMap.put(CreditResourceDirectory.DEPARTMENTID_KEY, "责任科室 ");
                aliasMap.put(CreditResourceDirectory.FUNCTIONS_KEY, "职能  ");
                aliasMap.put(CreditResourceDirectory.CREDITINFORECORD_KEY, "目录名称(信用信息记录)  ");
                aliasMap.put(CreditResourceDirectory.ATTRIBUTEID_KEY, "属性id  ");
                aliasMap.put(CreditResourceDirectory.PURVIEWID_KEY, "权限id ");
                aliasMap.put(CreditResourceDirectory.PUBLISHSTATE_KEY, "发布状态  ");
                aliasMap.put(CreditResourceDirectory.TABLENAME_KEY, "表名 ");
                aliasMap.put(CreditResourceDirectory.SHAREPERM_KEY, "公开范围  ");
                aliasMap.put(CreditResourceDirectory.DETAILCOLUMN_KEY, "显示详情 ");
                aliasMap.put(CreditResourceDirectory.TIMECOLUMN_KEY, "记录入库时间的字段  ");

                return aliasMap;

        }

        protected Map<String,String> getVKAliasMap(){
                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put("主键 ", CreditResourceDirectory.ID_KEY);
                aliasMap.put("单位id ", CreditResourceDirectory.MEMBERUNITID_KEY);
                aliasMap.put("目录名称  ", CreditResourceDirectory.CREDIRNAME_KEY);
                aliasMap.put("数据项 ", CreditResourceDirectory.DATAITEM_KEY);
                aliasMap.put("目录类别  ", CreditResourceDirectory.DIRTYPEID_KEY);
                aliasMap.put("共享权限 ", CreditResourceDirectory.SHAREPERMID_KEY);
                aliasMap.put("主题类别  ", CreditResourceDirectory.MAINTYPEID_KEY);
                aliasMap.put("创建时间  ", CreditResourceDirectory.CREATETIME_KEY);
                aliasMap.put("创建人  ", CreditResourceDirectory.CREATEUSER_KEY);
                aliasMap.put("责任科室 ", CreditResourceDirectory.DEPARTMENTID_KEY);
                aliasMap.put("职能  ", CreditResourceDirectory.FUNCTIONS_KEY);
                aliasMap.put("目录名称(信用信息记录)  ", CreditResourceDirectory.CREDITINFORECORD_KEY);
                aliasMap.put("属性id  ", CreditResourceDirectory.ATTRIBUTEID_KEY);
                aliasMap.put("权限id ", CreditResourceDirectory.PURVIEWID_KEY);
                aliasMap.put("发布状态  ", CreditResourceDirectory.PUBLISHSTATE_KEY);
                aliasMap.put("表名 ", CreditResourceDirectory.TABLENAME_KEY);
                aliasMap.put("公开范围  ", CreditResourceDirectory.SHAREPERM_KEY);
                aliasMap.put("显示详情 ", CreditResourceDirectory.DETAILCOLUMN_KEY);
                aliasMap.put("记录入库时间的字段  ", CreditResourceDirectory.TIMECOLUMN_KEY);

                return aliasMap;
        }



}
