package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.DishonestyAnalysisService;
import com.philisense.www.service.EnterpriseDishonestyTrackingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"dishonestyanalysis")
@Api(tags = "DishonestyAnalysisControllerForWeb|一个用来操作-{失信预测趋势分析}-业务模块的控制器")
public class DishonestyAnalysisControllerForWeb extends BaseUtilController{

        @Autowired
        private EnterpriseDishonestyTrackingService enterpriseDishonestyTrackingService;

        @Autowired
        private DishonestyAnalysisService dishonestyAnalysisService;


        @PostMapping("/selectQyxxQuery")
        @ApiOperation(value="根据-{企业信息目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "xydm", value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "zs", value = "住所  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "hymh", value = "行业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "fddbr", value = "法人名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信息目录表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object> selectQyxxQuery(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseDishonestyTrackingService.selectQyxxCount(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseDishonestyTrackingService.selectQyxxQuery(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //失信预测趋势分析折线图
        @PostMapping( "/selectQyDishonestyLine")
        @ApiOperation(value="根据-{失信预测趋势分析}-对象Map统计预警折线图", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "xydm", value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "begtime", value = "开始时间  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "endtime", value = "结束时间  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{失信预测趋势分析}-对象Map统计预警折线图",value = "query",type = "PC")
        public Map<String, Object>  selectQyDishonestyLine(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        if(map.get("state").equals("y"))
                        {
                          result.put(DATALIST, dishonestyAnalysisService.selectQyDishonestyYearLine(map));
                        }
                        else {
                          result.put(DATALIST, dishonestyAnalysisService.selectQyDishonestyMoonLine(map));
                        }
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


}
