package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.EnterpriseDishonestyTracking;
import com.philisense.www.service.EnterpriseCreditRankingService;
import com.philisense.www.service.EnterpriseNormService;
import com.philisense.www.service.ExponentialAlgorithmService;
import com.philisense.www.service.LabelManageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "enterprisecreditranking")
@Api(tags = "EnterpriseCreditRankingControllerForWeb|一个用来操作-{企业信用排名}-业务模块的控制器")
public class EnterpriseCreditRankingControllerForWeb extends BaseUtilController {

    @Autowired
    private ExponentialAlgorithmService exponentialAlgorithmService;

    @Autowired
    private LabelManageService labelManageService;

    @Autowired
    private EnterpriseCreditRankingService enterpriseCreditRankingService;

    @Autowired
    private EnterpriseNormService enterpriseNormService;

    public String getCurrentYear() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
        Date date = new Date();
        return sdf.format(date);
    }

    @PostMapping("/selectQyxxRankingList")
    @ApiOperation(value = "根据-{企业信用排名}-对象Map分页记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "xydm", value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "zs", value = "地区 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "bzs", value = "指数  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "hymh", value = "行业名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "startTime", value = "开始月份  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "endTime", value = "结束月份  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{企业信用排名}-对象Map分页记录", value = "query", type = "PC")
    public Map<String, Object> selectQyxxRankingList(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {

        Map<String, Object> result = new HashMap<String, Object>();

        String year = getCurrentYear();

        try {

            int currentPage = map.get(DATACURRENT) != null ? Integer.parseInt(map.get(DATACURRENT) + "") - 1 : 0;
            int pageSize = map.get(PAGESIZE) != null ? Integer.parseInt(map.get(PAGESIZE) + "") : 10;
            int pageStart = currentPage * pageSize;
            map.put(PAGESIZE, pageSize);
            map.put(PAGESTART, pageStart);

            int total = enterpriseCreditRankingService.selectQyxxRankingCount(map);
            List<Map<String, Object>> datalist = enterpriseCreditRankingService.selectQyxxRankingList(map);
            List<Map<String, Object>> pmlist = new ArrayList<Map<String, Object>>();
            if (total > 0) {
                for (Map<String, Object> maps : datalist) {

                    map.put("xydm", maps.get("xydm"));

                    if(map.get("begTime")==null || map.get("endTime")==null)
                    {
                        Map<String, Object> normMap = enterpriseNormService.selectByPrimaryName(maps.get("xydm").toString());
                        if(normMap!=null)
                        {
                            maps.put("bzs", normMap.get("score"));
                        }
                        else {
                            map.put("begTime", year + "-01");
                            map.put("endTime", year + "-12");
                            maps.put("bzs", getAllMapTree(map));
                        }
                    }
                    else {
                        maps.put("bzs", getAllMapTree(map));
                    }

                    pmlist.add(maps);
                }
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST, pmlist.stream().sorted((h1, h2) -> ((Float)h2.get("bzs")).compareTo((Float)h1.get("bzs"))).collect(Collectors.toList()));
            tempresult.put(DATATOTAL, total);
            tempresult.put(PAGESIZE, map.get(PAGESIZE) != null ? map.get(PAGESIZE) : 10);
            tempresult.put(DATACURRENT, map.get(DATACURRENT) != null ? map.get(DATACURRENT) : 0);
            result.put(DATARESULT, tempresult);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    //临时 统计信用指数报告 根据 企业统一代码 开始时间 结束时间 统计分数

    public Double getAllMapTree(Map<String, Object> map) {

        Double qyzs = 0D;

        DecimalFormat df = new DecimalFormat("#.##");

        List<Map<String, Object>> zssfMap = exponentialAlgorithmService.selectExponentialAlgorithm(map);

        List<Object> dlmids = zssfMap.stream().map(q -> q.get("dlmid")).distinct().collect(Collectors.toList());

        List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();

        if (null != zssfMap && zssfMap.size() > 0) {//指数设置项目-3

            for (int l = 0; l < dlmids.size(); l++) {

                Map<String, Object> labelMap = new HashMap<String, Object>();

                Double bqsz = 0D;//标签数值

                Double number = 0D;//数量

                Double addScore = 0D;//加减分

                labelMap.put("dlmid", dlmids.get(l));//标签id

                for (Map<String, Object> zssf : zssfMap) {//查询指数设置表

                    if (zssf.get("dlmid").equals(dlmids.get(l))) {//指数设置上级id

                        number = Double.valueOf(zssf.get("number").toString());
                        addScore = Double.valueOf((zssf.get("addScore").toString()));
                        labelMap.put("dlmparentid", zssf.get("dlmparentid"));//标签上级id
                        labelMap.put("baseScore", zssf.get("baseScore"));
                        labelMap.put("addScore", zssf.get("addScore"));
                        labelMap.put("number", number);
                        map.put("typeName", zssf.get("typeName"));
                        if (zssf.get("tableName").equals("b10"))//行政处罚 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzcfCount(map) + "");
                        } else if (zssf.get("tableName").equals("b16"))//行政奖励 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzjlCount(map) + "");
                        } else if (zssf.get("tableName").equals("xz_fy_sxbzxrmdxx"))//失信行为 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.sxxwCount(map) + "");
                        } else {//默认 - 统计
                            bqsz = bqsz + 0D;
                        }

                        //计算分值
                        bqsz = Double.valueOf(df.format(bqsz));//通过选择标签属性获取到对应的分数（必填项）

                    }

                }

                Double fs = Double.valueOf(df.format(addScore * bqsz));

                labelMap.put("score", fs);//标签权重

                data.add(labelMap);

            }

            List<Map<String, Object>> labeldata1 = selectLabelManageForWeb(data);

            if (null != labeldata1 && labeldata1.size() > 0) {
                for (Map<String, Object> list : labeldata1) {
                    Map<String, Object> labelMap = new HashMap<String, Object>();
                    labelMap.put("number", list.get("number"));
                    labelMap.put("score", list.get("score"));//标签权重
                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                    data.add(labelMap);
                }

                List<Map<String, Object>> labeldata2 = selectLabelManageForWeb(labeldata1);

                if (null != labeldata2 && labeldata2.size() > 0) {
                    for (Map<String, Object> list : labeldata2) {
                        Map<String, Object> labelMap = new HashMap<String, Object>();
                        labelMap.put("number", list.get("number"));
                        labelMap.put("score", list.get("score"));//标签权重
                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                        data.add(labelMap);
                    }

                    List<Map<String, Object>> labeldata3 = selectLabelManageForWeb(labeldata2);

                    if (null != labeldata3 && labeldata3.size() > 0) {
                        for (Map<String, Object> list : labeldata3) {
                            Map<String, Object> labelMap = new HashMap<String, Object>();
                            labelMap.put("number", list.get("number"));
                            labelMap.put("score", list.get("score"));//标签权重
                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                            data.add(labelMap);
                            qyzs = Double.valueOf(list.get("score").toString());
                        }
                    }
                }
            }
        }

        return qyzs;

    }

    public List<Map<String, Object>> selectLabelManageForWeb(List<Map<String, Object>> data) {

        DecimalFormat df = new DecimalFormat("#.##");

        List<Map<String, Object>> labeldata = new ArrayList<Map<String, Object>>();

        List<Object> dlmparentids = data.stream().map(q -> q.get("dlmparentid")).distinct().collect(Collectors.toList());

        for (int p = 0; p < dlmparentids.size(); p++) {
            Map<String, Object> labelMap = new HashMap<String, Object>();

            Double bqsz = 0D;//标签分值

            Double number = 0D;//权重信息

            Double baseScore = 0D;//基础分

            if (!"0".equals(dlmparentids.get(p).toString())) {
                Map<String, Object> plabelMap = labelManageService.selectByPrimaryKey(dlmparentids.get(p).toString());
                if (plabelMap.size() > 0 && plabelMap != null) {

                    for (Map<String, Object> pmap : data) {
                        if (pmap.get("dlmparentid").equals(dlmparentids.get(p).toString())) {
                            bqsz = bqsz + Double.valueOf(pmap.get("score").toString());
                            number = Double.valueOf(pmap.get("number").toString());
                        }
                    }

                    if (number > 0) {
                        number = number / 100;
                    } else {
                        number = 1D;
                    }

                    if (plabelMap.get("baseScore") != null) {
                        if (Double.valueOf(plabelMap.get("baseScore").toString()) > 0) {
                            baseScore = Double.valueOf(plabelMap.get("baseScore").toString());
                        }
                    }

                    bqsz = Double.valueOf(df.format(baseScore + bqsz));

                    Double fs = Double.valueOf(df.format(bqsz * number));

                    labelMap.put("score", fs);//标签权重
                    labelMap.put("dlmid", plabelMap.get("id"));//标签id
                    labelMap.put("dlmparentid", plabelMap.get("parentId"));//标签上级id
                    labelMap.put("number", plabelMap.get("score"));
                    labeldata.add(labelMap);
                }
            }
        }
        return labeldata;

    }


}
