package com.philisense.www.controller.web;

import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import cn.hutool.poi.word.WordUtil;
import com.deepoove.poi.XWPFTemplate;
import com.deepoove.poi.data.MiniTableRenderData;
import com.deepoove.poi.data.RowRenderData;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.EnterpriseInformationPublicity;
import com.philisense.www.service.*;
import com.philisense.www.utils.EncodeUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ResourceLoader;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@EnableScheduling
@EnableAsync
@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"enterpriseinformationpublicity")
@Api(tags = "EnterpriseInformationPublicityControllerForWeb|一个用来操作-{信用信息公示目录表|信用信息联合查询}-业务模块的控制器(author:xxg)")
public class EnterpriseInformationPublicityControllerForWeb extends BaseUtilController{

        @Autowired
        private EnterpriseInformationPublicityService enterpriseInformationPublicityService;

//        @Resource
//        ResourceLoader resourceLoader;

        @Autowired
        private EnterpriseNormService enterpriseNormService;

        @Autowired
        private ExponentialAlgorithmService exponentialAlgorithmService;

        @Autowired
        private LabelManageService labelManageService;

        public String getCurrentYear() {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
                Date date = new Date();
                return sdf.format(date);
        }

        @Async
        @Scheduled(cron = "0 0 2 1,7,28 * ?")
        public void catalogueTask() {

                Map<String, Object> map = new HashMap<String, Object>();

                SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy");
                SimpleDateFormat sdf2 = new SimpleDateFormat("MM");

                map.put("bTime", sdf1.format(new Date())+"-"+sdf2.format(new Date()));

                map.put("eTime", sdf1.format(new Date())+"-"+sdf2.format(new Date()));

                Map<String, Object> list = enterpriseInformationPublicityService.getOne(map);

                if(list==null)
                {
                        map.put("begTime", sdf1.format(new Date())+"-"+sdf2.format(new Date()));

                        map.put("endTime", sdf1.format(new Date())+"-"+sdf2.format(new Date()));

                        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                        map.put("title", sdf1.format(new Date())+"年"+sdf2.format(new Date())+"月企业信用信息公示");

                        map.put("createTime", new Date());

                        enterpriseInformationPublicityService.insert(map);

                }

                if(sdf2.format(new Date()).equals("12"))
                {
                        Map<String, Object> maps = new HashMap<String, Object>();

                        maps.put("bTime", sdf1.format(new Date())+"-01");

                        maps.put("eTime", sdf1.format(new Date())+"-12");

                        Map<String, Object> lists = enterpriseInformationPublicityService.getOne(maps);

                        if(lists==null)
                        {
                                maps.put("begTime", sdf1.format(new Date())+"-01");

                                maps.put("endTime", sdf1.format(new Date())+"-12");

                                maps.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                                maps.put("title", sdf1.format(new Date())+"年企业信用信息公示");

                                maps.put("createTime", new Date());

                                enterpriseInformationPublicityService.insert(maps);
                        }

                }

        }

        @Async
        @Scheduled(cron = "0 0 0/12 * * ?")
        public void a05ScoreTask()
        {

                Map<String, Object> map = new HashMap<String, Object>();
                String year = getCurrentYear();
                map.put("begTime", year + "-01");
                map.put("endTime", year + "-12");
                List<Map<String, Object>> datalist = enterpriseNormService.selectQyxxList(map);

                for (Map<String, Object> maps : datalist) {
                        String xydm = maps.get("xydm").toString();
                        map.put("xydm", xydm);
                        Map<String, Object> normMap = enterpriseNormService.selectByPrimaryName(xydm);
                        if(normMap==null)
                        {
                                normMap = new HashMap<String, Object>();
                                normMap.put("paramName",maps.get("qymc").toString());
                                normMap.put("isValid",1);
                                normMap.put("score",getAllMapTree(map));
                                normMap.put("id",UUID.randomUUID().toString().replaceAll("-", ""));
                                normMap.put("paramDm",xydm);
                                enterpriseNormService.insertQyxx(normMap);
                        }
                        else {
                                normMap.put("score",getAllMapTree(map));
                                enterpriseNormService.update(normMap);
                        }

                }

        }

        public Double getAllMapTree(Map<String, Object> map) {

                Double qyzs = 0D;

                DecimalFormat df = new DecimalFormat("#.##");

                List<Map<String, Object>> zssfMap = exponentialAlgorithmService.selectExponentialAlgorithm(map);

                List<Object> dlmids = zssfMap.stream().map(q -> q.get("dlmid")).distinct().collect(Collectors.toList());

                List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();

                if (null != zssfMap && zssfMap.size() > 0) {//指数设置项目-3

                        for (int l = 0; l < dlmids.size(); l++) {

                                Map<String, Object> labelMap = new HashMap<String, Object>();

                                Double bqsz = 0D;//标签数值

                                Double number = 0D;//数量

                                Double addScore = 0D;//加减分

                                labelMap.put("dlmid", dlmids.get(l));//标签id

                                for (Map<String, Object> zssf : zssfMap) {//查询指数设置表

                                        if (zssf.get("dlmid").equals(dlmids.get(l))) {//指数设置上级id

                                                number = Double.valueOf(zssf.get("number").toString());
                                                addScore = Double.valueOf((zssf.get("addScore").toString()));
                                                labelMap.put("dlmparentid", zssf.get("dlmparentid"));//标签上级id
                                                labelMap.put("baseScore", zssf.get("baseScore"));
                                                labelMap.put("addScore", zssf.get("addScore"));
                                                labelMap.put("number", number);
                                                map.put("typeName", zssf.get("typeName"));
                                                if (zssf.get("tableName").equals("b10"))//行政处罚 - 统计
                                                {
                                                        bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzcfCount(map) + "");
                                                } else if (zssf.get("tableName").equals("b16"))//行政奖励 - 统计
                                                {
                                                        bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzjlCount(map) + "");
                                                } else if (zssf.get("tableName").equals("xz_fy_sxbzxrmdxx"))//失信行为 - 统计
                                                {
                                                        bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.sxxwCount(map) + "");
                                                } else {//默认 - 统计
                                                        bqsz = bqsz + 0D;
                                                }

                                                //计算分值
                                                bqsz = Double.valueOf(df.format(bqsz));//通过选择标签属性获取到对应的分数（必填项）

                                        }

                                }

                                Double fs = Double.valueOf(df.format(addScore * bqsz));

                                labelMap.put("score", fs);//标签权重

                                data.add(labelMap);

                        }

                        List<Map<String, Object>> labeldata1 = selectLabelManageForWeb(data);

                        if (null != labeldata1 && labeldata1.size() > 0) {
                                for (Map<String, Object> list : labeldata1) {
                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                        labelMap.put("number", list.get("number"));
                                        labelMap.put("score", list.get("score"));//标签权重
                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                        data.add(labelMap);
                                }

                                List<Map<String, Object>> labeldata2 = selectLabelManageForWeb(labeldata1);

                                if (null != labeldata2 && labeldata2.size() > 0) {
                                        for (Map<String, Object> list : labeldata2) {
                                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                                labelMap.put("number", list.get("number"));
                                                labelMap.put("score", list.get("score"));//标签权重
                                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                data.add(labelMap);
                                        }

                                        List<Map<String, Object>> labeldata3 = selectLabelManageForWeb(labeldata2);

                                        if (null != labeldata3 && labeldata3.size() > 0) {
                                                for (Map<String, Object> list : labeldata3) {
                                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                                        labelMap.put("number", list.get("number"));
                                                        labelMap.put("score", list.get("score"));//标签权重
                                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                        data.add(labelMap);
                                                        qyzs = Double.valueOf(list.get("score").toString());
                                                }
                                        }
                                }
                        }
                }

                return qyzs;

        }

        public List<Map<String, Object>> selectLabelManageForWeb(List<Map<String, Object>> data) {

                DecimalFormat df = new DecimalFormat("#.##");

                List<Map<String, Object>> labeldata = new ArrayList<Map<String, Object>>();

                List<Object> dlmparentids = data.stream().map(q -> q.get("dlmparentid")).distinct().collect(Collectors.toList());

                for (int p = 0; p < dlmparentids.size(); p++) {
                        Map<String, Object> labelMap = new HashMap<String, Object>();

                        Double bqsz = 0D;//标签分值

                        Double number = 0D;//权重信息

                        Double baseScore = 0D;//基础分

                        if (!"0".equals(dlmparentids.get(p).toString())) {
                                Map<String, Object> plabelMap = labelManageService.selectByPrimaryKey(dlmparentids.get(p).toString());
                                if (plabelMap.size() > 0 && plabelMap != null) {

                                        for (Map<String, Object> pmap : data) {
                                                if (pmap.get("dlmparentid").equals(dlmparentids.get(p).toString())) {
                                                        bqsz = bqsz + Double.valueOf(pmap.get("score").toString());
                                                        number = Double.valueOf(pmap.get("number").toString());
                                                }
                                        }

                                        if (number > 0) {
                                                number = number / 100;
                                        } else {
                                                number = 1D;
                                        }

                                        if (plabelMap.get("baseScore") != null) {
                                                if (Double.valueOf(plabelMap.get("baseScore").toString()) > 0) {
                                                        baseScore = Double.valueOf(plabelMap.get("baseScore").toString());
                                                }
                                        }

                                        bqsz = Double.valueOf(df.format(baseScore + bqsz));

                                        Double fs = Double.valueOf(df.format(bqsz * number));

                                        labelMap.put("score", fs);//标签权重
                                        labelMap.put("dlmid", plabelMap.get("id"));//标签id
                                        labelMap.put("dlmparentid", plabelMap.get("parentId"));//标签上级id
                                        labelMap.put("number", plabelMap.get("score"));
                                        labeldata.add(labelMap);
                                }
                        }
                }
                return labeldata;

        }

        @GetMapping( "/a05")
        @ApiOperation(value="根据-{{统计企业分值}}-对象Map导出所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @OperateLog(name = "根据-{{统计企业分值}}-对象Map导出所有记录",value = "query",type = "PC")
        public Map<String, Object> a05()
        {
                Map<String, Object> result = new HashMap<String, Object>();
                a05ScoreTask();
                Map<String, Object> tempresult = new HashMap<String, Object>();
                tempresult.put(DATASUCCESS, SUCCESSFLAG);
                tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARESULT, tempresult);
                return result;
        }

        //分页显示详情-》失信行为名单
        @PostMapping( "/queryPageSxxw")
        @ApiOperation(value="根据-{开始日期-结束日期}-查询信用信息公示记录-失信行为名单", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="query", name = "begTime", value = "开始日期 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="query", name = "endTime", value = "结束日期  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{开始日期-结束日期}-查询信用信息公示记录-失信行为名单",value = "query",type = "PC")
        public Map<String, Object>  queryPageSxxw(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseInformationPublicityService.countSxxw(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseInformationPublicityService.queryPageSxxw(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        //分页显示详情-》良好信用信息
        @PostMapping( "/queryPageLhxy")
        @ApiOperation(value="根据-{开始日期-结束日期}-查询信用信息公示记录-良好信用信息", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="query", name = "begTime", value = "开始日期 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="query", name = "endTime", value = "结束日期  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{开始日期-结束日期}-查询信用信息公示记录-良好信用信息",value = "query",type = "PC")
        public Map<String, Object>  queryPageLhxy(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseInformationPublicityService.countLhxy(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseInformationPublicityService.queryPageLhxy(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @GetMapping("/view")
        @ApiOperation(value="根据-{开始日期-结束日期}-查询信用信息公示记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="query", name = "begTime", value = "开始日期 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="query", name = "endTime", value = "结束日期  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{开始日期-结束日期}-查看企业信用信息公示详情",value = "query",type = "PC")
        public Map<String, Object> view(HttpServletRequest request , HttpServletResponse response ,@RequestParam("begTime")String begTime,@RequestParam("endTime")String endTime)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
//                        List<Map<String, String>> list0 = enterpriseInformationPublicityService.selectSxsjQuery(begTime,endTime);
//                        List<Map<String, String>> list1 = enterpriseInformationPublicityService.selectQyycQuery(begTime,endTime);
//                        List<Map<String, String>> list2 = enterpriseInformationPublicityService.selectGtjyQuery(begTime,endTime);
//                        List<Map<String, String>> list3 = enterpriseInformationPublicityService.selectXzcfQuery(begTime,endTime);
//
//                        List<Map<String, String>> list4 = enterpriseInformationPublicityService.selectXzjlQuery(begTime,endTime);
//                        List<Map<String, String>> list5 = enterpriseInformationPublicityService.selectXypjQuery(begTime,endTime);
//
//                        result.put("sxsj", list0);//失信事件
//                        result.put("qyyc", list1);//企业异常
//                        result.put("gtjy", list2);//个体经营
//                        result.put("xzcf", list3);//行政处罚
//
//                        result.put("xzjl", list4);//行政奖励
//                        result.put("xypj", list5);//信用评价

                        List<Map<String, String>> list6 = enterpriseInformationPublicityService.selectSxxwmdQuery(begTime,endTime);
                        List<Map<String, String>> list7 = enterpriseInformationPublicityService.selectLhxyxxQuery(begTime,endTime);

                        list7.sort(Comparator.comparing((Map<String, String> h) -> (h.get("date"))).reversed());  //倒序

                        list6.sort(Comparator.comparing((Map<String, String> h) -> (h.get("date"))).reversed());  //倒序

                        result.put("sxxwmd", list6);//失信行为名单

                        result.put("lhxyxx", list7);//良好信用信息

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @PostMapping( "/selectQyxxQuery")
        @ApiOperation(value="根据-{企业信息目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "xydm", value = "统一社会信用代码 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "zs", value = "住所  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "hymh", value = "行业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "fddbr", value = "法人名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信息目录表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  selectQyxxQuery(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseInformationPublicityService.selectQyxxCount(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseInformationPublicityService.selectQyxxQuery(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @GetMapping("/qyxxView")
        @ApiOperation(value="根据-{统一社会信用代码}-信用信息联合查询", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="query", name = "xydm", value = "统一社会信用代码 ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{统一社会信用代码}-查看企业信用信息联合详情",value = "query",type = "PC")
        public Map<String, Object> qyxxView(HttpServletRequest request , HttpServletResponse response ,@RequestParam("xydm")String xydm)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        List<Map<String, Object>> list0 = enterpriseInformationPublicityService.selectQyXzcfQuery(xydm);
                        List<Map<String, Object>> list1 = enterpriseInformationPublicityService.selectQyXzjlQuery(xydm);
                        List<Map<String, Object>> list2 = enterpriseInformationPublicityService.selectQyZzzgQuery(xydm);
                        Map<String, Object> map = new HashMap<String, Object>();
                        map.put("xydm",xydm);
                        List<Map<String, Object>> list3 = enterpriseInformationPublicityService.selectQyxxQuery(map);

                        result.put("xzcf", list0);//行政处罚
                        result.put("xzjl", list1);//行政奖励
                        result.put("zzzg", list2);//资质资格
                        result.put("qyxx", list3);//企业信息
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //信用信息联合查询->导出word功能

        private final static Map<String,String> zzzgKey = new LinkedHashMap<>();

        private final static Map<String,String> xzcfKey = new LinkedHashMap<>();

        private final static Map<String,String> xzjlKey = new LinkedHashMap<>();

        //初始化表格字段，表格的字段生成顺序和插入顺序一致，默认一排两个字段(map的key为数据库字段名，value为字段中文名)
        static {
                //初始化资质认证表格key
                zzzgKey.put("jgmc","机构名称");
                zzzgKey.put("tyshxydm","统一社会信用代码");
                zzzgKey.put("dmlx","代码类型");
                zzzgKey.put("dm","代码");
                zzzgKey.put("zzdj","资质等级");
                zzzgKey.put("zzqsrq","资质起始日期");
                zzzgKey.put("zzjsrq","资质结束日期");
                zzzgKey.put("zzbfjg","资质颁发机关");
                zzzgKey.put("zzbfjgtyshxydm","资质颁发机关统一社会信用代码");
                zzzgKey.put("zzbfrq","资质颁发日期");
                zzzgKey.put("bz","备注");
                zzzgKey.put("creater_time","创建时间");

                //初始化处罚信息表格key
                xzcfKey.put("xzxdrmc","行政相对人名称");
                xzcfKey.put("xzxdrlb","行政相对人类别");
                xzcfKey.put("xzxdrdm1","行政相对人代码_1(统一社会信用代码)");
                xzcfKey.put("fddbrxm","法定代表人姓名");
                xzcfKey.put("fddbrzzlx","法定代表人证件类型");
                xzcfKey.put("fddbrzzhm","法定代表人证件号码");
                xzcfKey.put("xzcfjdwsh","行政处罚决定文书号");
                xzcfKey.put("wfxwlx","违法行为类型");
                xzcfKey.put("wfss","违法事实");
                xzcfKey.put("cfyj","处罚依据");
                xzcfKey.put("cflb","处罚类别");
                xzcfKey.put("cfnr","处罚内容");
                xzcfKey.put("fkje","罚款金额");
                xzcfKey.put("cfjdrq","处罚决定日期");
                xzcfKey.put("bz","备注");
                xzcfKey.put("creater_time","创建时间");

                //初始化奖励信息表格key
                xzjlKey.put("xzxdrmc","行政相对人名称");
                xzjlKey.put("xzxdrlb","行政相对人类别");
                xzjlKey.put("xzxdrdm1","行政相对人代码_1(统一社会信用代码)");
                xzjlKey.put("fddbrxm","法定代表人姓名");
                xzjlKey.put("fddbrzzlx","法定代表人证件类型");
                xzjlKey.put("fddbrzzhm","法定代表人证件号码");
                xzjlKey.put("rdwsh","认定文书号");
                xzjlKey.put("jlmc","奖励名称");
                xzjlKey.put("jlsx","奖励事项");
                xzjlKey.put("jlxs","奖励形式");
                xzjlKey.put("jljb","奖励级别");
                xzjlKey.put("jlsyrq","奖励授予日期");
                xzjlKey.put("jlzsmc","奖励证书名称");
                xzjlKey.put("syjgmc","授予机构名称");
                xzjlKey.put("bz","备注");
                xzjlKey.put("creater_time","创建时间");

        }

        @GetMapping( "/installCreditReportWord")
        @ApiOperation(value="根据统一信用代码下载企业信用报告", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "xydm", value = "统一信用代码", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据统一信用代码下载企业信用报告",value = "query",type = "PC")
        public void installCreditReportWord(HttpServletRequest request , HttpServletResponse response, @RequestParam String xydm)
        {

                if (StringUtils.isBlank(xydm)) {
                        xydm = "915400916868219536";
                }

                Map<String, Object> result = new HashMap<String, Object>();

                Map<String,Object> data = new HashMap<>();

                Map<String, Object> map = new HashMap<String, Object>();

                map.put("xydm",xydm);

                List<Map<String, Object>> qyxx = enterpriseInformationPublicityService.selectQyxxQuery(map);

                if(!CollectionUtils.isEmpty(qyxx)){

                        //String line = System.getProperty("line.separator");

                        data.put("zzmc", qyxx.get(0).get("zzmc"));
                        data.put("zzdm", qyxx.get(0).get("zzdm"));
                        data.put("tyshxydm", qyxx.get(0).get("tyshxydm"));
                        data.put("qymc", qyxx.get(0).get("zzmc"));
                        data.put("nsrsbh", qyxx.get(0).get("nsrsbh"));
                        data.put("jyzt", qyxx.get(0).get("jyzt"));
                        data.put("hyml", qyxx.get(0).get("hymh"));
                        data.put("clrq", qyxx.get(0).get("clrq"));
                        data.put("djjg", qyxx.get(0).get("djglbmmc"));
                        data.put("jyfw", qyxx.get(0).get("ywfw"));
                        data.put("yyqx", qyxx.get(0).get("yyqx"));
                        data.put("hzrq", qyxx.get(0).get("hzrq"));
                        data.put("gszch", qyxx.get(0).get("gszch"));
                        data.put("qy", qyxx.get(0).get("qy"));
                        data.put("zs", qyxx.get(0).get("zcdz"));
                        data.put("zzmcs", qyxx.get(0).get("zzmcs"));
                        data.put("zczbbz", qyxx.get(0).get("zczbbz"));
                        data.put("fddbrxm", qyxx.get(0).get("fddbrxm"));
                        data.put("zzdjrq", qyxx.get(0).get("zzdjrq"));

                        List<Map<String, Object>> xzcf = enterpriseInformationPublicityService.selectQyXzcfQuery(xydm);
                        List<Map<String, Object>> xzjl = enterpriseInformationPublicityService.selectQyXzjlQuery(xydm);
                        List<Map<String, Object>> zzzg = enterpriseInformationPublicityService.selectQyZzzgQuery(xydm);

                        try {

                                handleZzzg(data, zzzg);//资质认证信息

                                handleXzcf(data, xzcf);//处罚信息

                                handleXzjl(data, xzjl);//奖励信息

                                result.put(DATASUCCESS, SUCCESSFLAG);

                                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);

                                XWPFTemplate template = XWPFTemplate.compile(WordUtil.class.getClassLoader().getResourceAsStream("wordTemplate/enterpriseinformationpublicity/enterpriseinformationpublicity.docx")).render(data);
                                //中文文件名编码处理
                                String filename = qyxx.get(0).get("qymc")+"企业信用信息报告.docx";
                                String encode = EncodeUtils.getEncoding(filename);
                                if(StringUtils.isNotBlank(encode) && !"ISO-8859-1".equals(encode)){//匹配到编码
                                        filename = new String(filename.getBytes(encode), StandardCharsets.ISO_8859_1);
                                }
                                //response为HttpServletResponse对象
                                response.setContentType("application/octet-stream");
                                response.setCharacterEncoding("utf-8");
                                //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                                response.setHeader("Content-Disposition","attachment;filename="+filename);
                                ServletOutputStream out=response.getOutputStream();
                                template.write(out);
                                out.flush();
                                //此处记得关闭输出Servlet流
                                IoUtil.close(out);
                                // 关闭xwpfTemplate，释放内存
                                template.close();


                        }catch(Exception e){
                                e.printStackTrace();
                        }



                }


        }

        private void handleZzzg(Map<String, Object> data, List<Map<String, Object>> zzzg) {
                if(!CollectionUtils.isEmpty(zzzg)){
                        //资质认证
                        List<Map<String,Object>> zzzgs = new ArrayList<>();
                        for (int i = 0; i < zzzg.size(); i++) {
                                Map<String,Object> item = zzzg.get(i);
                                //构建资质认证名称
                                Map<String,Object> map = new HashMap<>();
                                map.put("name","资质认证_记录"+(i+1));
                                //构建资质认证记录表格
                                createTableData(item, map,zzzgKey);
                                zzzgs.add(map);
                        }
                        data.put("zzzg", zzzgs);
                }
        }

        private void handleXzcf(Map<String, Object> data, List<Map<String, Object>> xzcf) {
                if(!CollectionUtils.isEmpty(xzcf)){
                        //处罚信息
                        List<Map<String,Object>> xzcfs = new ArrayList<>();
                        for (int i = 0; i < xzcf.size(); i++) {
                                Map<String,Object> item = xzcf.get(i);
                                //构建处罚信息名称
                                Map<String,Object> map = new HashMap<>();
                                map.put("name","处罚信息_记录"+(i+1));
                                //构建处罚信息记录表格
                                createTableData(item, map,xzcfKey);
                                xzcfs.add(map);
                        }
                        data.put("xzcf", xzcfs);
                }
        }

        private void handleXzjl(Map<String, Object> data, List<Map<String, Object>> xzjl) {
                if(!CollectionUtils.isEmpty(xzjl)){
                        //奖励信息
                        List<Map<String,Object>> xzjls = new ArrayList<>();
                        for (int i = 0; i < xzjl.size(); i++) {
                                Map<String,Object> item = xzjl.get(i);
                                //构建奖励信息名称
                                Map<String,Object> map = new HashMap<>();
                                map.put("name","奖励信息_记录"+(i+1));
                                //构建奖励信息记录表格
                                createTableData(item, map,xzjlKey);
                                xzjls.add(map);
                        }
                        data.put("xzjl", xzjls);
                }
        }

        private void createTableData(Map<String, Object> item, Map<String, Object> map,Map<String,String> tableKey) {
                List<RowRenderData> collect = new ArrayList<>();
                if(!CollectionUtils.isEmpty(tableKey)){
                        Map<String,String> rowIndex = new HashMap<>();
                        rowIndex.put("index","0");
                        tableKey.forEach((key,value)->{
                                if("1".equals(rowIndex.get("index"))){
                                        rowIndex.put("key2",key);
                                        rowIndex.put("value2",value);
                                        rowIndex.put("index","2");
                                }

                                if("0".equals(rowIndex.get("index"))){
                                        rowIndex.put("key1",key);
                                        rowIndex.put("value1",value);
                                        rowIndex.put("index","1");
                                }

                                if("2".equals(rowIndex.get("index"))){
                                        String key1 = rowIndex.get("key1");
                                        String key2 = rowIndex.get("key2");
                                        rowIndex.put("index","0");
                                        collect.add(RowRenderData.build(tableKey.get(key1),  item.get(key1)+"", tableKey.get(key2), item.get(key2)+""));
                                }

                        });
                        if("1".equals(rowIndex.get("index"))){//表示最后一行多了一个
                                String key1 = rowIndex.get("key1");
                                collect.add(RowRenderData.build(tableKey.get(key1), item.get(key1)+""));

                        }
                }
                map.put("data",new MiniTableRenderData(collect));
        }

        //信用信息联合查询->导出word功能

        //@GetMapping( "/delete")
        //@ApiOperation(value="根据-{信用信息公示目录表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        //@ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        //@OperateLog(name = "根据-{信用信息公示目录表}-主键删除记录",value = "delete",type = "PC")
        public Map<String, Object> deleteByPrimaryKeyForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = enterpriseInformationPublicityService.deleteByPrimaryKey(recordid);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @GetMapping( "/get")
//        @ApiOperation(value="根据-{信用信息公示目录表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
//        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
//        @OperateLog(name = "根据-{信用信息公示目录表}-主键查询记录",value = "query",type = "PC")
        public Map<String, Object> selectByPrimaryKeyForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, enterpriseInformationPublicityService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/insert")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                        enterpriseInformationPublicityService.insert(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/update")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        Map<String, Object> paramsmap = enterpriseInformationPublicityService.selectByPrimaryKey(map.get("id")+"");

                        int flag = 0;

                        if( null!=paramsmap &&paramsmap.size()>0) {
                                paramsmap.putAll(map);
                                flag = enterpriseInformationPublicityService.update(paramsmap);
                        }

                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/deleteByMap")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteByMapForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = enterpriseInformationPublicityService.deleteByMap(map);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/updateByMap")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateByMapForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        int flag = enterpriseInformationPublicityService.updateByMap(map);
                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
//        @PostMapping( "/getOne")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map查询记录",value = "query",type = "PC")
        public Map<String, Object>  getOneForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, enterpriseInformationPublicityService.getOne(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/getAll")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map查询所有记录",value = "query",type = "PC")
        public Map<String, Object>  getAllForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, enterpriseInformationPublicityService.getAll(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseInformationPublicityService.count(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseInformationPublicityService.queryPage(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map统计查询总数记录",value = "query",type = "PC")
        public Map<String, Object>  countForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATATOTAL, enterpriseInformationPublicityService.count(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/insertBatch")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map批量插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertBatchForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        for(Map<String, Object> map:list){
                                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                        }

                        enterpriseInformationPublicityService.insertBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/deleteBatch")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map批量删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteBatchForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        enterpriseInformationPublicityService.deleteBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

//        @PostMapping( "/updateBatch")
//        @ApiOperation(value="根据-{信用信息公示目录表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{信用信息公示目录表}-对象Map批量更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateBatchForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        enterpriseInformationPublicityService.updateBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }





//        @GetMapping( "/export")
//        @ApiOperation(value="根据-{{信用信息公示目录表}}-对象Map导出所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{{信用信息公示目录表}}-对象Map导出所有记录",value = "query",type = "PC")
        public void exportForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        List<Map<String, Object>> rows = enterpriseInformationPublicityService.getAll(map);
                        // 通过工具类创建writer
                        //创建xlsx格式的
                        ExcelWriter writer = ExcelUtil.getWriter(true);
                        String filename = "信用信息公示目录表";
                        getWriter(writer,filename);
                        writer.setHeaderAlias(getKVAliasMap());


                        writer.setOnlyAlias(true);

                        // 一次性写出内容，使用默认样式，强制输出标题
                        writer.write(rows, true);

                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_EnterpriseInformationPublicity.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        writer.flush(out, true);
                        // 关闭writer，释放内存
                        writer.close();
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



//        @GetMapping( "/exportTemplate")
//        @ApiOperation(value="根据-{{信用信息公示目录表}}-下载导出模板", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{{信用信息公示目录表}}-下载导出模板",value = "query",type = "PC")
        public void exportTemplateForEnterpriseInformationPublicityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        String filename = "信用信息公示目录表";
                        InputStream resource = getClass().getClassLoader().getResourceAsStream("excelTemplate/enterpriseinformationpublicity" + "/"+filename+"_EnterpriseInformationPublicity.xlsx");
                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_EnterpriseInformationPublicity.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        IoUtil.copy(resource,out);
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);
                        IoUtil.close(resource);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



//        @PostMapping( "/importExcel")
//        @ApiOperation(value="根据-{{信用信息公示目录表}}-对象Map批量导入记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
//        @ApiImplicitParams({
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.TITLE, value = "信用信息公示标题 ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.CREATETIME_KEY, value = "创建时间  ", required = true, dataTypeClass = Date.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
//                @ApiImplicitParam(paramType="body", name = EnterpriseInformationPublicity.ENDTIME, value = "结束日期  ", required = true, dataTypeClass = String.class)
//        })
//        @OperateLog(name = "根据-{{信用信息公示目录表}}-对象Map批量导入记录",value = "update",type = "PC")
        public Map<String, Object>  importExcelForEnterpriseInformationPublicityForWeb(String baseDir, MultipartFile file) {
                Map<String, Object> result = new HashMap<String, Object>();

                if (!file.isEmpty()) {
                        try {
                                ExcelReader reader = ExcelUtil.getReader(file.getInputStream());

                                reader.setHeaderAlias(getVKAliasMap());


                                List<Map<String, Object>> list = new ArrayList<>();
                                List<Map<String, Object>> read = reader.read(1, 2, Integer.MAX_VALUE);

                                for (Map<String,Object> map:read){


                                        if ("".equals(map.get(EnterpriseInformationPublicity.ID_KEY))){
                                                map.put(EnterpriseInformationPublicity.ID_KEY,null);
                                        }

                                        if ("".equals(map.get(EnterpriseInformationPublicity.TITLE))){
                                                map.put(EnterpriseInformationPublicity.TITLE,null);
                                        }

                                        if ("".equals(map.get(EnterpriseInformationPublicity.CREATETIME_KEY))){
                                                map.put(EnterpriseInformationPublicity.CREATETIME_KEY,null);
                                        }

                                        if ("".equals(map.get(EnterpriseInformationPublicity.BEGTIME))){
                                                map.put(EnterpriseInformationPublicity.BEGTIME,null);
                                        }

                                        if ("".equals(map.get(EnterpriseInformationPublicity.ENDTIME))){
                                                map.put(EnterpriseInformationPublicity.ENDTIME,null);
                                        }

                                        list.add(map);

                                }
                                enterpriseInformationPublicityService.insertBatch(list);

                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                        } catch (FileNotFoundException e) {
                                e.printStackTrace();
                        } catch (IOException e) {
                                e.printStackTrace();
                        }
                }
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG);
                return result;
        }



        protected void getWriter(ExcelWriter writer,String filename){
                // 通过工具类创建writer
                //创建xlsx格式的
                writer.setColumnWidth(0,25);
                writer.setColumnWidth(1,25);
                writer.setColumnWidth(2,25);
                writer.setColumnWidth(3,25);
                writer.setColumnWidth(4,25);
                // 合并单元格后的标题行，使用默认标题样式
                writer.merge(4, filename);

        }



        protected Map<String,String> getKVAliasMap(){

                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put(EnterpriseInformationPublicity.ID_KEY, "主键 ");
                aliasMap.put(EnterpriseInformationPublicity.TITLE, "信用信息公示标题 ");
                aliasMap.put(EnterpriseInformationPublicity.CREATETIME_KEY, "创建时间  ");
                aliasMap.put(EnterpriseInformationPublicity.BEGTIME, "开始日期  ");
                aliasMap.put(EnterpriseInformationPublicity.ENDTIME, "结束日期  ");
                return aliasMap;

        }

        protected Map<String,String> getVKAliasMap(){
                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put("主键 ", EnterpriseInformationPublicity.ID_KEY);
                aliasMap.put("信用信息公示标题 ", EnterpriseInformationPublicity.TITLE);
                aliasMap.put("创建时间  ", EnterpriseInformationPublicity.CREATETIME_KEY);
                aliasMap.put("开始日期 ", EnterpriseInformationPublicity.BEGTIME);
                aliasMap.put("结束日期 ", EnterpriseInformationPublicity.ENDTIME);
                return aliasMap;
        }



}
