package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.EnterpriseNormService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "enterprisenorm")
@Api(tags = "EnterpriseNormControllerForWeb |一个用来操作-{企业信用排名指标}-业务模块的控制器")
public class EnterpriseNormControllerForWeb extends BaseUtilController {


    @Autowired
    private EnterpriseNormService enterpriseNormService;


    @PostMapping("/selectNormList")
    @ApiOperation(value = "根据-{企业信用排名指标}-对象Map分页记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "paramName", value = "参数名", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "isValid", value = "是否生效", required = true, dataTypeClass = Integer.class)
    })
    @OperateLog(name = "根据-{企业信用排名指标}-对象Map分页记录", value = "query", type = "PC")
    public Map<String, Object> selectNormList(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
            int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
            int pageStart = currentPage*pageSize ;

            map.put(PAGESIZE,pageSize);
            map.put(PAGESTART,pageStart);

            int total = enterpriseNormService.selectNormCount(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if(total>0){
                datalist = enterpriseNormService.selectNormList(map);
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST,datalist);
            tempresult.put(DATATOTAL,total);
            tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
            tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
            result.put(DATARESULT, tempresult);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
    }

    @PostMapping( "/update")
    @ApiOperation(value="根据-{企业信用排名指标}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "id", value = "主键", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "isValid", value = "是否生效", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "paramName", value = "参数名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "score", value = "分值", required = true, dataTypeClass = Integer.class)
    })
    @OperateLog(name = "根据-{企业信用排名指标}-对象更新记录",value = "update",type = "PC")
    public Map<String, Object>  updateForEnterpriseNormForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
    {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            Map<String, Object> paramsmap = enterpriseNormService.selectByPrimaryKey(map.get("id")+"");

            int flag = 0;

            if( null!=paramsmap &&paramsmap.size()>0) {
                paramsmap.putAll(map);
                flag = enterpriseNormService.update(paramsmap);
            }

            if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
    }

    @GetMapping( "/delete")
    @ApiOperation(value="根据-{企业信用排名指标}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParam(paramType="query", name = "id", value = "主键", required = true,  dataTypeClass = String.class)
    @OperateLog(name = "根据-{企业信用排名指标}-主键删除记录",value = "delete",type = "PC")
    public Map<String, Object> deleteByPrimaryKeyForEnterpriseNormForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String id)
    {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = enterpriseNormService.deleteByPrimaryKey(id);
            if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
    }

    @GetMapping( "/get")
    @ApiOperation(value="根据-{企业信用排名指标}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParam(paramType="query", name = "id", value = "主键", required = true,  dataTypeClass = String.class)
    @OperateLog(name = "根据-{企业信用排名指标}-主键查询记录",value = "query",type = "PC")
    public Map<String, Object> selectByPrimaryKeyForEnterpriseNormForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String id)
    {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, enterpriseNormService.selectByPrimaryKey(id));
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
    }

    @PostMapping( "/insert")
    @ApiOperation(value="根据-{企业信用排名指标}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "paramName", value = "参数名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "isValid", value = "是否生效", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "score", value = "分值", required = true, dataTypeClass = Integer.class)
    })
    @OperateLog(name = "根据-{企业信用排名指标}-对象插入记录",value = "insert",type = "PC")
    public Map<String, Object>  insertForXzGysyGyjtCcrpwwgxxForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
    {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

            enterpriseNormService.insert(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
    }
}
