package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.EnterpriseRelationNetworkService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "relationnetwork")
@Api(tags = "EnterpriseRelationNetworkControllerForWeb |一个用来操作-{企业关系网分析}-业务模块的控制器")
public class EnterpriseRelationNetworkControllerForWeb extends BaseUtilController {


    @Autowired
    private EnterpriseRelationNetworkService enterpriseRelationNetworkService;


    @PostMapping("/selectChildren")
    @ApiOperation(value = "根据-{当前企业基本信息}-获取当前企业子公司关系网", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "xydm", value = "统一社会信用代码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "qymc", value = "企业名称", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{当前企业基本信息}-使用图表列举出当前企业的子公司关系网", value = "query", type = "PC")
    public Map<String, Object> selectChildren(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, String> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> maplist = enterpriseRelationNetworkService.selectChildren(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARESULT, maplist);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        System.out.println(result);
        return result;
    }
    @PostMapping("/selectParents")
    @ApiOperation(value = "根据-{当前企业基本信息}-获取当前企业的被控股关系网", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "xydm", value = "统一社会信用代码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "qymc", value = "企业名称", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{当前企业基本信息}-使用图表列举出当前企业的被控股关系网", value = "query", type = "PC")
    public Map<String, Object> selectParents(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, String> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> maplist = enterpriseRelationNetworkService.selectParents(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARESULT, maplist);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        System.out.println(result);
        return result;
    }
    @PostMapping("/selectCompetitor")
    @ApiOperation(value = "根据-{当前企业基本信息}-获取当前企业的竞争对手关系网", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "xydm", value = "统一社会信用代码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "qymc", value = "企业名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "hydm", value = "行业代码", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{当前企业基本信息}-使用图表列举出当前企业的竞争对手关系网", value = "query", type = "PC")
    public Map<String, Object> selectCompetitor(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, String> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> maplist = enterpriseRelationNetworkService.selectCompetitor(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARESULT, maplist);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        System.out.println(result);
        return result;
    }
    @PostMapping("/selectPartner")
    @ApiOperation(value = "根据-{当前企业基本信息}-获取当前企业的战略企业关系网", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "xydm", value = "统一社会信用代码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "qymc", value = "企业名称", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{当前企业基本信息}-使用图表列举出当前企业的战略企业关系网", value = "query", type = "PC")
    public Map<String, Object> selectPartner(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, String> map) {

        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> maplist = enterpriseRelationNetworkService.selectPartner(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARESULT, maplist);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        System.out.println(result);
        return result;
    }

}
