package com.philisense.www.controller.web;

import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.EnterpriseWarning;
import com.philisense.www.service.EnterpriseWarningService;
import com.philisense.www.utils.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"enterprisewarning")
@Api(tags = "EnterpriseWarningControllerForWeb|一个用来操作-{企业信用风险预警}-业务模块的控制器")
public class EnterpriseWarningControllerForWeb extends BaseUtilController{

        @Autowired
        private EnterpriseWarningService enterpriseWarningService;

        //预警列表
        @PostMapping( "/selectQyWarnList")
        @ApiOperation(value="根据-{企业信用风险预警列表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "state", value = "预警等级 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "warning", value = "预警类型  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警列表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  selectQyWarnList(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        if (StringUtils.isNotNull(map.get("state"))){
                            String state = String.valueOf(map.get("state"));
                            if ("1".equals(state)){
                                    map.put("state","一级预警");
                            }else if ("2".equals(state)){
                                        map.put("state","二级预警");
                            }else if ("3".equals(state)){
                                    map.put("state","三级预警");
                            }
                        }
                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseWarningService.selectQyWarnCount(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseWarningService.selectQyWarnList(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //预警统计数量
        @PostMapping( "/selectQyWarnNumber")
        @ApiOperation(value="根据-{企业信用风险预警统计分析}-对象Map统计预警数量", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "state", value = "预警等级 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "warning", value = "预警类型  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "begtime", value = "开始时间  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "endtime", value = "结束时间  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警统计分析}-对象Map统计预警数量",value = "query",type = "PC")
        public Map<String, Object>  selectQyWarnNumber(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, enterpriseWarningService.selectQyWarnNumber(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //预警统计柱状图
        @PostMapping( "/selectQyWarnBar")
        @ApiOperation(value="根据-{企业信用风险预警统计分析}-对象Map统计预警柱状图", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "state", value = "预警等级 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "warning", value = "预警类型  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "begtime", value = "开始时间  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "endtime", value = "结束时间  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警统计分析}-对象Map统计预警柱状图",value = "query",type = "PC")
        public Map<String, Object>  selectQyWarnBar(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, enterpriseWarningService.selectQyWarnBar(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //预警统计饼状图
        @PostMapping( "/selectQyWarnPie")
        @ApiOperation(value="根据-{企业信用风险预警统计分析}-对象Map统计预警饼状图", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "state", value = "预警等级 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "warning", value = "预警类型  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "qymc", value = "企业名称  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "begtime", value = "开始时间  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "endtime", value = "结束时间  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警统计分析}-对象Map统计预警饼状图",value = "query",type = "PC")
        public Map<String, Object>  selectQyWarnPie(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        //result.put(DATALIST, enterpriseWarningService.selectQyWarnPie(map));
                        List<Map<String, Object>> list = enterpriseWarningService.selectQyWarnPie(map);
                        List<Map<String, Object>> pie1 = list.stream().filter(a -> a.get("state").toString().equals("一级预警")).collect(Collectors.toList());
                        List<Map<String, Object>> pie2 = list.stream().filter(a -> a.get("state").toString().equals("二级预警")).collect(Collectors.toList());
                        List<Map<String, Object>> pie3 = list.stream().filter(a -> a.get("state").toString().equals("三级预警")).collect(Collectors.toList());
                        result.put("data1", pie1);
                        result.put("data2", pie2);
                        result.put("data3", pie3);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{企业信用风险预警}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{企业信用风险预警}-主键删除记录",value = "delete",type = "PC")
        public Map<String, Object> deleteByPrimaryKeyForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = enterpriseWarningService.deleteByPrimaryKey(recordid);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{企业信用风险预警}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{企业信用风险预警}-主键查询记录",value = "query",type = "PC")
        public Map<String, Object> selectByPrimaryKeyForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, enterpriseWarningService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{企业信用风险预警}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                        enterpriseWarningService.insert(map);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{企业信用风险自定义预警设置}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险自定义预警设置}-对象更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        Map<String, Object> paramsmap = enterpriseWarningService.selectByPrimaryKey(map.get("id")+"");

                        int flag = 0;

                        if( null!=paramsmap &&paramsmap.size()>0) {
                                paramsmap.putAll(map);
                                flag = enterpriseWarningService.update(paramsmap);
                        }

                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteByMapForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        int flag = enterpriseWarningService.deleteByMap(map);
                        if(1<=flag) {
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateByMapForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        int flag = enterpriseWarningService.updateByMap(map);
                        if(1<=flag){
                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                        }else{
                                result.put(DATASUCCESS, ERRORFLAG);
                                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                        }

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map查询记录",value = "query",type = "PC")
        public Map<String, Object>  getOneForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATARECORD, enterpriseWarningService.getOne(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map查询所有记录",value = "query",type = "PC")
        public Map<String, Object>  getAllForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST, enterpriseWarningService.getAll(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{企业信用风险自定义预警设置}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险自定义预警设置}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = enterpriseWarningService.count(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = enterpriseWarningService.queryPage(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map统计查询总数记录",value = "query",type = "PC")
        public Map<String, Object>  countForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATATOTAL, enterpriseWarningService.count(map));
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map批量插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertBatchForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        for(Map<String, Object> map:list){
                                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                        }

                        enterpriseWarningService.insertBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map批量删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteBatchForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        enterpriseWarningService.deleteBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{企业信用风险预警}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{企业信用风险预警}-对象Map批量更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateBatchForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        enterpriseWarningService.updateBatch(list);
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }





        @GetMapping( "/export")
        @ApiOperation(value="根据-{{企业信用风险预警}}-对象Map导出所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{{企业信用风险预警}}-对象Map导出所有记录",value = "query",type = "PC")
        public void exportForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        List<Map<String, Object>> rows = enterpriseWarningService.getAll(map);
                        // 通过工具类创建writer
                        //创建xlsx格式的
                        ExcelWriter writer = ExcelUtil.getWriter(true);
                        String filename = "企业信用风险预警";
                        getWriter(writer,filename);
                        writer.setHeaderAlias(getKVAliasMap());


                        writer.setOnlyAlias(true);

                        // 一次性写出内容，使用默认样式，强制输出标题
                        writer.write(rows, true);

                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_EnterpriseWarning.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        writer.flush(out, true);
                        // 关闭writer，释放内存
                        writer.close();
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



        @GetMapping( "/exportTemplate")
        @ApiOperation(value="根据-{{企业信用风险预警}}-下载导出模板", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{{企业信用风险预警}}-下载导出模板",value = "query",type = "PC")
        public void exportTemplateForEnterpriseWarningForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        String filename = "企业信用风险预警";
                        InputStream resource = getClass().getClassLoader().getResourceAsStream("excelTemplate/EnterpriseWarning" + "/"+filename+"_EnterpriseWarning.xlsx");
                        //response为HttpServletResponse对象
                        response.setContentType("application/vnd.ms-excel;charset=utf-8");
                        //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                        response.setHeader("Content-Disposition","attachment;filename="+filename+"_EnterpriseWarning.xlsx");
                        ServletOutputStream out=response.getOutputStream();
                        IoUtil.copy(resource,out);
                        //此处记得关闭输出Servlet流
                        IoUtil.close(out);
                        IoUtil.close(resource);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
        }



        @PostMapping( "/importExcel")
        @ApiOperation(value="根据-{{企业信用风险预警}}-对象Map批量导入记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.WARNING, value = "预警类型名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = EnterpriseWarning.STATE, value = "预警等级  ", required = true, dataTypeClass = Integer.class)
        })
        @OperateLog(name = "根据-{{企业信用风险预警}}-对象Map批量导入记录",value = "update",type = "PC")
        public Map<String, Object>  importExcelForEnterpriseWarningForWeb(String baseDir, MultipartFile file) {
                Map<String, Object> result = new HashMap<String, Object>();

                if (!file.isEmpty()) {
                        try {
                                ExcelReader reader = ExcelUtil.getReader(file.getInputStream());

                                reader.setHeaderAlias(getVKAliasMap());


                                List<Map<String, Object>> list = new ArrayList<>();
                                List<Map<String, Object>> read = reader.read(1, 2, Integer.MAX_VALUE);

                                for (Map<String,Object> map:read){


                                        if ("".equals(map.get(EnterpriseWarning.ID_KEY))){
                                                map.put(EnterpriseWarning.ID_KEY,null);
                                        }

                                        if ("".equals(map.get(EnterpriseWarning.WARNING))){
                                                map.put(EnterpriseWarning.WARNING,null);
                                        }

                                        if ("".equals(map.get(EnterpriseWarning.STATE))){
                                                map.put(EnterpriseWarning.STATE,null);
                                        }

                                        list.add(map);

                                }
                                enterpriseWarningService.insertBatch(list);

                                result.put(DATASUCCESS, SUCCESSFLAG);
                                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                        } catch (FileNotFoundException e) {
                                e.printStackTrace();
                        } catch (IOException e) {
                                e.printStackTrace();
                        }
                }
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG);
                return result;
        }



        protected void getWriter(ExcelWriter writer,String filename){
                // 通过工具类创建writer
                //创建xlsx格式的
                writer.setColumnWidth(0,25);
                writer.setColumnWidth(1,25);
                writer.setColumnWidth(2,25);
                // 合并单元格后的标题行，使用默认标题样式
                writer.merge(3, filename);

        }



        protected Map<String,String> getKVAliasMap(){

                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put(EnterpriseWarning.ID_KEY, "主键 ");
                aliasMap.put(EnterpriseWarning.WARNING, "预警类型名称 ");
                aliasMap.put(EnterpriseWarning.STATE, "预警等级  ");
                return aliasMap;

        }

        protected Map<String,String> getVKAliasMap(){
                Map<String,String> aliasMap = new LinkedHashMap<>();

                aliasMap.put("主键 ", EnterpriseWarning.ID_KEY);
                aliasMap.put("预警类型名称 ", EnterpriseWarning.WARNING);
                aliasMap.put("预警等级  ", EnterpriseWarning.STATE);
                return aliasMap;
        }



}
