package com.philisense.www.controller.web;

import cn.hutool.core.io.IoUtil;
import cn.hutool.core.lang.func.Func;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import cn.hutool.poi.word.WordUtil;
import com.deepoove.poi.XWPFTemplate;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.pojos.entity.CreditIndexReport;
import com.philisense.www.pojos.entity.LabelManage;
import com.philisense.www.pojos.vo.ExponentialAlgorithmVo;
import com.philisense.www.pojos.vo.LabelManageVo;
import com.philisense.www.service.EnterpriseInformationPublicityService;
import com.philisense.www.service.ExponentialAlgorithmService;
import com.philisense.www.service.LabelManageService;
import com.philisense.www.utils.DateTimeUtils;
import com.philisense.www.utils.EncodeUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ResourceLoader;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "labelmanage")
@Api(tags = "LabelManageControllerForWeb|一个用来操作-{信用指数报告标签}-标签管理业务模块的控制器(author:xxg)")
public class LabelManageControllerForWeb extends BaseUtilController {

    @Autowired
    private LabelManageService labelManageService;//标签管理

    @Autowired
    private ExponentialAlgorithmService exponentialAlgorithmService;//指数算法

//    @Resource
//    ResourceLoader resourceLoader;

    @Autowired
    private EnterpriseInformationPublicityService enterpriseInformationPublicityService;

    public static void main(String[] args) {
    }

    public String getCurrentYear(){
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
        Date date = new Date();
        return sdf.format(date);
    }

    //信用指数报告 - 下拉框选择项目
    @GetMapping("/xyzsSelect")
    @ApiOperation(value = "根据-{信用指数报告标签管理删除接口}-主键删除记录(包括指数算法数据)", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @OperateLog(name = "根据-{信用指数报告下拉框}-(行政处罚，行政奖励，失信行为)", value = "query", type = "PC")
    public List<ExponentialAlgorithmVo> xyzsSelect() {

        List<ExponentialAlgorithmVo> list = new ArrayList<ExponentialAlgorithmVo>();

        String[] xzcfId = {"01", "02", "03", "04", "05", "06"
                , "99"};
        String[] xzcfName = {"警告", "罚款", "没收违法所得、没收非法财物", "责令停产停业", "暂扣或者吊销许可证、暂扣或者吊销执照", "行政拘留"
                , "法律行政法规规定的其他行政处罚"};

        //行政处罚
        int num = 1;
        for(int i=0;i<xzcfId.length;i++)
        {
            ExponentialAlgorithmVo xzcf = new ExponentialAlgorithmVo();
            xzcf.setCompute("+");
            xzcf.setOrderNum(num);
            xzcf.setTableName("b10");
            xzcf.setAnnotate(xzcfName[i]);
            xzcf.setXydm("xzxdrdm");
            xzcf.setType("cflb");
            xzcf.setTypeName(xzcfId[i]);
            xzcf.setRq("cfjdrq");
            list.add(xzcf);
            num++;
        }

        String[] jlxsId = {"0", "1", "2", "3", "4", "5"
                , "9"};
        String[] jlxsName = {"发给奖金或奖品", "通报表扬", "通令嘉奖", "记功", "授予荣誉称号", "晋级或晋职"
                , "其他"};

        for(int i=0;i<jlxsId.length;i++)
        {
            ExponentialAlgorithmVo jlxs = new ExponentialAlgorithmVo();
            jlxs.setCompute("+");
            jlxs.setOrderNum(num);
            jlxs.setTableName("b16");
            jlxs.setAnnotate(jlxsName[i]);
            jlxs.setXydm("xzxdrdm");
            jlxs.setType("jlxs");
            jlxs.setTypeName(jlxsId[i]);
            jlxs.setRq("jlsyrq");
            list.add(jlxs);
            num++;
        }

        String[] sxxwId = {"0", "1", "2", "3", "4", "5"
                , "6", "7", "8"};
        String[] sxxwName = {"被执行人无正当理由拒不履行执行和解协议", "其他规避执行", "有履行能力而拒不履行生效法律文书确定义务", "暴力妨碍、抗拒执行,威胁妨碍、抗拒执行", "其他妨碍、抗拒执行", "违反财产报告制度"
                , "违反限制高消费令", "隐匿财产规避执行", "转移财产、规避执行"};

        for(int i=0;i<sxxwId.length;i++)
        {
            ExponentialAlgorithmVo sxxw = new ExponentialAlgorithmVo();
            sxxw.setCompute("+");
            sxxw.setOrderNum(num);
            sxxw.setTableName("xz_fy_sxbzxrmdxx");
            sxxw.setAnnotate(sxxwName[i]);
            sxxw.setXydm("fddbrzjhm");
            sxxw.setType("sxbzxrlxqk");
            sxxw.setTypeName(sxxwId[i]);
            sxxw.setRq("lasj");
            list.add(sxxw);
            num++;
        }

        return list;
    }


    @PostMapping("/getAllTree")
    @ApiOperation(value = "根据-{信用指数自定义报告详情}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TITLE, value = "标题 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.NAME, value = "名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.TYPE, value = "类型  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SCORE, value = "分数  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.REMARKS, value = "备注 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.QYMC, value = "企业（机构）名称  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.SORT, value = "排序  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.LEVEL, value = "级别  ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数自定义报告详情}-对象Map查询所有记录", value = "query", type = "PC")
    public Map<String, Object> getAllForCreditIndexReportsForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();

        String year = getCurrentYear();

        try {
            if (map.get("begTime")==null) {
                map.put("begTime",year+"-01");
            }
            if (map.get("endTime")==null) {
                map.put("endTime",year+"-12");
            }
            if (map.get("xydm")==null) {
                map.put("xydm","915400916868219536");
            }
            result.put(DATALIST, getAllMapTree(map));
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    //导出word
    @GetMapping("/installTreeDexreportForWord")
    @ApiOperation(value = "根据统一信用代码下载自定义信用指数报告", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.XYDM, value = "统一社会信用代码  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.BEGTIME, value = "开始日期  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = CreditIndexReport.ENDTIME, value = "结束日期 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据统一信用代码下载自定义信用指数报告", value = "query", type = "PC")
    public void installTreeDexreportForWord(HttpServletRequest request, HttpServletResponse response, @RequestParam String begTime, @RequestParam String endTime, @RequestParam String xydm) {

        String year = getCurrentYear();

        if (StringUtils.isBlank(begTime)) {
            begTime = year+"-01";
        }
        if (StringUtils.isBlank(endTime)) {
            endTime = year+"-12";
        }
        if (StringUtils.isBlank(xydm)) {
            xydm = "915400916868219536";
        }

        if (StringUtils.isNotBlank(endTime) && StringUtils.isNotBlank(begTime) && StringUtils.isNotBlank(xydm)) {
            Map<String, Object> map = new HashMap<String, Object>();
            Map<String, Object> datas = new HashMap<>();
            if (StringUtils.isNotBlank(xydm)) {
                map.put("xydm", xydm);
            }

            List<Map<String, Object>> qyxx = enterpriseInformationPublicityService.selectQyxxQuery(map);

            datas.put("zzmc", qyxx.get(0).get("zzmc"));
            datas.put("zzdm", qyxx.get(0).get("zzdm"));
            datas.put("tyshxydm", qyxx.get(0).get("tyshxydm"));
            datas.put("qymc", qyxx.get(0).get("zzmc"));
            datas.put("nsrsbh", qyxx.get(0).get("nsrsbh"));
            datas.put("jyzt", qyxx.get(0).get("jyzt"));
            datas.put("hyml", qyxx.get(0).get("hymh"));
            datas.put("clrq", qyxx.get(0).get("clrq"));
            datas.put("djjg", qyxx.get(0).get("djglbmmc"));
            datas.put("jyfw", qyxx.get(0).get("ywfw"));
            datas.put("yyqx", qyxx.get(0).get("yyqx"));
            datas.put("hzrq", qyxx.get(0).get("hzrq"));
            datas.put("gszch", qyxx.get(0).get("gszch"));
            datas.put("qy", qyxx.get(0).get("qy"));
            datas.put("zs", qyxx.get(0).get("zcdz"));
            datas.put("zzmcs", qyxx.get(0).get("zzmcs"));
            datas.put("zczbbz", qyxx.get(0).get("zczbbz"));
            datas.put("fddbrxm", qyxx.get(0).get("fddbrxm"));
            datas.put("zzdjrq", qyxx.get(0).get("zzdjrq"));

            datas.put("begTime", begTime);
            datas.put("endTime", endTime);

            map.put("begTime", begTime);
            map.put("endTime", endTime);
            map.put("xydm", qyxx.get(0).get("xydm"));

            try {

                datas.put("dataTree", getAllMapTree(map));

                XWPFTemplate template = XWPFTemplate.compile(WordUtil.class.getClassLoader().getResourceAsStream("wordTemplate/creditindexreport/treedexreport.docx")).render(datas);
                //中文文件名编码处理
                String filename = qyxx.get(0).get("qymc") + "信用指数报告.docx";
                String encode = EncodeUtils.getEncoding(filename);
                if (StringUtils.isNotBlank(encode) && !"ISO-8859-1".equals(encode)) {//匹配到编码
                    filename = new String(filename.getBytes(encode), StandardCharsets.ISO_8859_1);
                }
                //response为HttpServletResponse对象
                response.setContentType("application/octet-stream");
                response.setCharacterEncoding("utf-8");
                //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
                response.setHeader("Content-Disposition", "attachment;filename=" + filename);
                ServletOutputStream out = response.getOutputStream();

                if(out!=null)
                {
                    template.write(out);
                    out.flush();
                    //此处记得关闭输出Servlet流
                    IoUtil.close(out);
                    // 关闭xwpfTemplate，释放内存
                    template.close();
                }

            } catch (Exception e) {
                e.printStackTrace();
            }
        }


    }


    //指数信息 树形列表
    public List<Map<String, Object>> getAllMapTree(Map<String, Object> map) {

        DecimalFormat df = new DecimalFormat("#.##");

        List<Map<String, Object>> zssfMap = exponentialAlgorithmService.selectExponentialAlgorithm(map);

        List<Object> dlmids = zssfMap.stream().map(q -> q.get("dlmid")).distinct().collect(Collectors.toList());

        List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();

        if (null != zssfMap && zssfMap.size() > 0) {//指数设置项目-3

            for (int l = 0; l < dlmids.size(); l++) {//上级目录da_label_manage主键id

                Map<String, Object> labelMap = new HashMap<String, Object>();

                Double bqsz = 0D;//标签数值

                Double number = 0D;//数量

                String name = "";//名称

                Double addScore = 0D;//加减分

                labelMap.put("dlmid", dlmids.get(l));//标签id

                for (Map<String, Object> zssf : zssfMap) {//查询指数设置表所有数据

                    if (zssf.get("dlmid").equals(dlmids.get(l))) {//指数设置上级id

                        number = Double.valueOf(zssf.get("number").toString());

                        addScore = Double.valueOf((zssf.get("addScore").toString()));

                        labelMap.put("dlmparentid", zssf.get("dlmparentid"));//标签上级id
                        labelMap.put("dlmlabelname", zssf.get("dlmlabelname"));//标签名称
                        labelMap.put("name", zssf.get("dlmlabelname"));//标签名称

                        labelMap.put("number", number);//第三层权重

                        name = zssf.get("dlmlabelname").toString();

                        labelMap.put("dlmscore", zssf.get("dlmscore"));//标签权重
                        labelMap.put("dlmattribute", zssf.get("dlmattribute"));//标签属性
                        labelMap.put("dlplabelname", zssf.get("dlplabelname"));//标签上级名称
                        labelMap.put("title", zssf.get("dlplabelname"));//标签上级名称
                        labelMap.put("announce", true);

                        labelMap.put("tableName", zssf.get("tableName"));
                        labelMap.put("annotate", zssf.get("annotate"));
                        labelMap.put("xydm", zssf.get("xydm"));
                        labelMap.put("type", zssf.get("type"));
                        labelMap.put("typeName", zssf.get("typeName"));
                        labelMap.put("rq", zssf.get("rq"));

                        labelMap.put("baseScore", zssf.get("baseScore"));
                        labelMap.put("addScore", zssf.get("addScore"));

                        map.put("typeName",zssf.get("typeName"));

                        if(zssf.get("tableName").equals("b10"))//行政处罚 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzcfCount(map)+"");
                        }
                        else if(zssf.get("tableName").equals("b16"))//行政奖励 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.xzjlCount(map)+"");
                        }
                        else if(zssf.get("tableName").equals("xz_fy_sxbzxrmdxx"))//失信行为 - 统计
                        {
                            bqsz = bqsz + Double.valueOf(exponentialAlgorithmService.sxxwCount(map)+"");
                        }
                        else {//默认 - 统计
                            bqsz = bqsz + 0D;
                        }

                        //计算分值
                        bqsz = Double.valueOf(df.format(bqsz));//通过选择标签属性获取到对应的分数（必填项）

                    }

                }

//                number = number / 100;

                Double fs = Double.valueOf(df.format(addScore * bqsz));

                labelMap.put("score", fs);//标签权重

                labelMap.put("bz", name + ",指标为" + fs);

                data.add(labelMap);

            }

            List<Map<String, Object>> labeldata1 = selectLabelManageForWeb(data);

            if (null != labeldata1 && labeldata1.size() > 0) {
                for (Map<String, Object> list : labeldata1) {
                    Map<String, Object> labelMap = new HashMap<String, Object>();
                    labelMap.put("number", list.get("number"));
                    labelMap.put("score", list.get("score"));//标签权重
                    labelMap.put("bz", list.get("bz"));
                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                    labelMap.put("name", list.get("name"));//标签名称
                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                    labelMap.put("title", list.get("title"));//标签上级名称
                    labelMap.put("announce", false);
                    labelMap.put("baseScore", list.get("baseScore"));
                    labelMap.put("addScore", list.get("addScore"));
                    data.add(labelMap);
                }

                List<Map<String, Object>> labeldata2 = selectLabelManageForWeb(labeldata1);

                if (null != labeldata2 && labeldata2.size() > 0) {
                    for (Map<String, Object> list : labeldata2) {
                        Map<String, Object> labelMap = new HashMap<String, Object>();
                        labelMap.put("number", list.get("number"));
                        labelMap.put("score", list.get("score"));//标签权重
                        labelMap.put("bz", list.get("bz"));
                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                        labelMap.put("name", list.get("name"));//标签名称
                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                        labelMap.put("title", list.get("title"));//标签上级名称
                        labelMap.put("announce", false);
                        labelMap.put("baseScore", list.get("baseScore"));
                        labelMap.put("addScore", list.get("addScore"));
                        data.add(labelMap);
                    }

                    List<Map<String, Object>> labeldata3 = selectLabelManageForWeb(labeldata2);

                    if (null != labeldata3 && labeldata3.size() > 0) {
                        for (Map<String, Object> list : labeldata3) {
                            Map<String, Object> labelMap = new HashMap<String, Object>();
                            labelMap.put("number", list.get("number"));
                            labelMap.put("score", list.get("score"));//标签权重
                            labelMap.put("bz", list.get("bz"));
                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                            labelMap.put("name", list.get("name"));//标签名称
                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                            labelMap.put("title", list.get("title"));//标签上级名称
                            labelMap.put("announce", false);
                            labelMap.put("baseScore", list.get("baseScore"));
                            labelMap.put("addScore", list.get("addScore"));
                            data.add(labelMap);
                        }

                        List<Map<String, Object>> labeldata4 = selectLabelManageForWeb(labeldata3);

                        if (null != labeldata4 && labeldata4.size() > 0) {
                            for (Map<String, Object> list : labeldata4) {
                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                labelMap.put("number", list.get("number"));
                                labelMap.put("score", list.get("score"));//标签权重
                                labelMap.put("bz", list.get("bz"));
                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                labelMap.put("name", list.get("name"));//标签名称
                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                labelMap.put("title", list.get("title"));//标签上级名称
                                labelMap.put("announce", false);
                                data.add(labelMap);
                            }

                            List<Map<String, Object>> labeldata5 = selectLabelManageForWeb(labeldata4);

                            if (null != labeldata5 && labeldata5.size() > 0) {
                                for (Map<String, Object> list : labeldata5) {
                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                    labelMap.put("number", list.get("number"));
                                    labelMap.put("score", list.get("score"));//标签权重
                                    labelMap.put("bz", list.get("bz"));
                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                    labelMap.put("name", list.get("name"));//标签名称
                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                    labelMap.put("title", list.get("title"));//标签上级名称
                                    labelMap.put("announce", false);
                                    data.add(labelMap);
                                }

                                List<Map<String, Object>> labeldata6 = selectLabelManageForWeb(labeldata5);

                                if (null != labeldata6 && labeldata6.size() > 0) {
                                    for (Map<String, Object> list : labeldata6) {
                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                        labelMap.put("number", list.get("number"));
                                        labelMap.put("score", list.get("score"));//标签权重
                                        labelMap.put("bz", list.get("bz"));
                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                        labelMap.put("name", list.get("name"));//标签名称
                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                        labelMap.put("title", list.get("title"));//标签上级名称
                                        labelMap.put("announce", false);
                                        data.add(labelMap);
                                    }

                                    List<Map<String, Object>> labeldata7 = selectLabelManageForWeb(labeldata6);

                                    if (null != labeldata7 && labeldata7.size() > 0) {
                                        for (Map<String, Object> list : labeldata7) {
                                            Map<String, Object> labelMap = new HashMap<String, Object>();
                                            labelMap.put("number", list.get("number"));
                                            labelMap.put("score", list.get("score"));//标签权重
                                            labelMap.put("bz", list.get("bz"));
                                            labelMap.put("dlmid", list.get("dlmid"));//标签id
                                            labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                            labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                            labelMap.put("name", list.get("name"));//标签名称
                                            labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                            labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                            labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                            labelMap.put("title", list.get("title"));//标签上级名称
                                            labelMap.put("announce", false);
                                            data.add(labelMap);
                                        }

                                        List<Map<String, Object>> labeldata8 = selectLabelManageForWeb(labeldata7);

                                        if (null != labeldata8 && labeldata8.size() > 0) {
                                            for (Map<String, Object> list : labeldata8) {
                                                Map<String, Object> labelMap = new HashMap<String, Object>();
                                                labelMap.put("number", list.get("number"));
                                                labelMap.put("score", list.get("score"));//标签权重
                                                labelMap.put("bz", list.get("bz"));
                                                labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                labelMap.put("name", list.get("name"));//标签名称
                                                labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                labelMap.put("title", list.get("title"));//标签上级名称
                                                labelMap.put("announce", false);
                                                data.add(labelMap);
                                            }

                                            List<Map<String, Object>> labeldata9 = selectLabelManageForWeb(labeldata8);

                                            if (null != labeldata9 && labeldata9.size() > 0) {
                                                for (Map<String, Object> list : labeldata9) {
                                                    Map<String, Object> labelMap = new HashMap<String, Object>();
                                                    labelMap.put("number", list.get("number"));
                                                    labelMap.put("score", list.get("score"));//标签权重
                                                    labelMap.put("bz", list.get("bz"));
                                                    labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                    labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                    labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                    labelMap.put("name", list.get("name"));//标签名称
                                                    labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                    labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                    labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                    labelMap.put("title", list.get("title"));//标签上级名称
                                                    labelMap.put("announce", false);
                                                    data.add(labelMap);
                                                }

                                                List<Map<String, Object>> labeldata10 = selectLabelManageForWeb(labeldata9);

                                                if (null != labeldata10 && labeldata10.size() > 0) {
                                                    for (Map<String, Object> list : labeldata10) {
                                                        Map<String, Object> labelMap = new HashMap<String, Object>();
                                                        labelMap.put("number", list.get("number"));
                                                        labelMap.put("score", list.get("score"));//标签权重
                                                        labelMap.put("bz", list.get("bz"));
                                                        labelMap.put("dlmid", list.get("dlmid"));//标签id
                                                        labelMap.put("dlmparentid", list.get("dlmparentid"));//标签上级id
                                                        labelMap.put("dlmlabelname", list.get("dlmlabelname"));//标签名称
                                                        labelMap.put("name", list.get("name"));//标签名称
                                                        labelMap.put("dlmscore", list.get("dlmscore"));//标签权重
                                                        labelMap.put("dlmattribute", list.get("dlmattribute"));//标签属性
                                                        labelMap.put("dlplabelname", list.get("dlplabelname"));//标签上级名称
                                                        labelMap.put("title", list.get("title"));//标签上级名称
                                                        labelMap.put("announce", false);
                                                        data.add(labelMap);
                                                    }
                                                }
                                            }

                                        }
                                    }

                                }

                            }

                        }

                    }

                }


            }


        }

        List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

        if (data.size() > 0) {

            if (null != data && data.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : data) {
                    tree.put("id", tree.get("dlmid"));
                    tree.put("parentid", tree.get("dlmparentid"));
                    if (tree.get("dlmid").equals("1")) {
                        parenttreedata.add(tree);
                    }

                }

                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                for (Map<String, Object> ptree : parenttreedata) {
                    Integer xh = 1;
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            tree.put("xh", xh + "、");
                            second_treedata.add(tree);
                            sontreedata.add(tree);
                            xh++;
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    Integer xh = 1;
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            tree.put("xh", "(" + xh + ") ");
                            third_treedata.add(tree);
                            sontreedata.add(tree);
                            xh++;
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点


                //四级树节点
                for (Map<String, Object> ptree : third_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            fourth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                //五级树节点
                for (Map<String, Object> ptree : fourth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            fifth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                //六级树节点
                for (Map<String, Object> ptree : fifth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            sixth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //七级树节点
                for (Map<String, Object> ptree : sixth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            seventh_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //八级树节点
                for (Map<String, Object> ptree : seventh_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            eighth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //九级树节点
                for (Map<String, Object> ptree : eighth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            nineth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //十级树节点
                for (Map<String, Object> ptree : nineth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : data) {
                        tree.put("id", tree.get("dlmid"));
                        tree.put("parentid", tree.get("dlmparentid"));
                        if (tree.get("dlmparentid").equals(ptree.get("dlmid"))) {
                            tenth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


            }

            //result.put(DATALIST, parenttreedata);
        }

        return parenttreedata;

    }

    public List<Map<String, Object>> selectLabelManageForWeb(List<Map<String, Object>> data) {
        //根据最下级目录获取到的数据 查询上级目录进行计算

        DecimalFormat df = new DecimalFormat("#.##");

        List<Map<String, Object>> labeldata = new ArrayList<Map<String, Object>>();

        List<Object> dlmparentids = data.stream().map(q -> q.get("dlmparentid")).distinct().collect(Collectors.toList());

        for (int p = 0; p < dlmparentids.size(); p++) {
            Map<String, Object> labelMap = new HashMap<String, Object>();

            Double bqsz = 0D;//标签分值

            Double number = 0D;//权重信息

            String bjname = "";//标签名称

            Double baseScore = 0D;//基础分

            if (!"0".equals(dlmparentids.get(p).toString())) {
                Map<String, Object> plabelMap = labelManageService.selectByPrimaryKey(dlmparentids.get(p).toString());
                if (plabelMap.size() > 0 && plabelMap != null) {

                    for (Map<String, Object> pmap : data) {
                        if (pmap.get("dlmparentid").equals(dlmparentids.get(p).toString())) {
                            bqsz = bqsz + Double.valueOf(pmap.get("score").toString());
                            bjname = bjname + "，" + pmap.get("name");
                            number = Double.valueOf(pmap.get("number").toString());
                        }
                    }

                    if(number>0)
                    {
                        number = number / 100;
                    }
                    else {
                        number = 1D;
                    }

                    if(plabelMap.get("baseScore")!=null)
                    {
                        if(Double.valueOf(plabelMap.get("baseScore").toString())>0)
                        {
                            baseScore = Double.valueOf(plabelMap.get("baseScore").toString());
                        }
                    }

                    bqsz = Double.valueOf(df.format(baseScore + bqsz));

                    Double fs = Double.valueOf(df.format(bqsz * number));

                    labelMap.put("score", fs);//标签权重

                    String bz = "综合" + bjname.substring(1, bjname.length()) + "指标，" + plabelMap.get("labelName") + "评估得分为" + fs + "分";

                    labelMap.put("bz", bz.replace("顶级目录", ""));

                    labelMap.put("dlmid", plabelMap.get("id"));//标签id
                    labelMap.put("dlmparentid", plabelMap.get("parentId"));//标签上级id
                    labelMap.put("dlmlabelname", plabelMap.get("labelName"));//标签名称
                    labelMap.put("name", plabelMap.get("labelName"));//标签名称
                    labelMap.put("dlmscore", plabelMap.get("score"));//标签权重
                    labelMap.put("dlmattribute", plabelMap.get("attribute"));//标签属性
                    labelMap.put("dlplabelname", plabelMap.get("parentName"));//标签上级名称
                    labelMap.put("title", plabelMap.get("parentName"));//标签上级名称
                    labelMap.put("number", plabelMap.get("score"));
                    labelMap.put("baseScore", plabelMap.get("baseScore"));
                    labelMap.put("addScore", plabelMap.get("addScore"));
                    labeldata.add(labelMap);

                }
            }

        }

        return labeldata;
        //根据最下级目录获取到的数据 查询上级目录进行计算
    }

    @GetMapping("/delete")
    @ApiOperation(value = "根据-{信用指数报告标签管理删除接口}-主键删除记录(包括指数算法数据)", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{信用指数报告标签管理删除接口}-主键删除记录(包括指数算法数据)", value = "delete", type = "PC")
    public Map<String, Object> deleteByPrimaryKeyForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> map = new HashMap<String, Object>();
            map.put("parentId", recordid);
            Integer num = labelManageService.count(map);
            if (num > 0) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, "存在下级标签,不允许删除");
            } else {
                Map<String, Object> eamap = new HashMap<String, Object>();
                eamap.put("labelId", recordid);//根据标签id删除算法表信息
                exponentialAlgorithmService.deleteByMap(eamap);
                int flag = labelManageService.deleteByPrimaryKey(recordid);
                if (1 <= flag) {
                    result.put(DATASUCCESS, SUCCESSFLAG);
                    result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                } else {
                    result.put(DATASUCCESS, ERRORFLAG);
                    result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @GetMapping("/get")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-主键查询记录(设置指数算法)", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{信用指数报告标签管理}-主键查询记录(设置指数算法)", value = "query", type = "PC")
    public Map<String, Object> selectByPrimaryKeyForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put("bqgl", labelManageService.selectByPrimaryKey(recordid));//标签管理信息
            Map<String, Object> eamap = new HashMap<String, Object>();
            eamap.put("labelId", recordid);//根据标签id查询算法表信息
            result.put("zssf", exponentialAlgorithmService.getAll(eamap));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insert")
    @ApiOperation(value = "根据-{信用指数报告标签管理新增接口}-对象插入记录(标签管理)", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.BASESCORE, value = "基础分  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ADDSCORE, value = "加减分  ", required = true, dataTypeClass = Double.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理新增接口}-对象插入记录(标签管理)", value = "insert", type = "PC")
    public Map<String, Object> insertForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

            Map<String, Object> map2 = new HashMap<String, Object>();
            map2.put("labelName", map.get("labelName"));
            Integer num = labelManageService.count(map2);
            if (num > 0) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, "失败，有相同的标签名称");
                return result;
            }

            if (map.get("parentId") != null && map.get("labelName") != null) {
                Map<String, Object> paramsmap = labelManageService.selectByPrimaryKey(map.get("parentId") + "");
                if (null != paramsmap && paramsmap.size() > 0) {
                    map.put("ancestors", paramsmap.get("ancestors") + "," + map.get("parentId"));
                    map.put("createBy", "管理员");
                    map.put("createTime", new Date());
                    map.put("delFlag", "0");

                    if(map.get("baseScore")!=null)
                    {
                        map.put("baseScore", map.get("baseScore"));
                    }
                    else {
                        map.put("baseScore", 100);
                    }

                    if(map.get("addScore")!=null)
                    {
                        map.put("addScore", map.get("addScore"));
                    }
                    else {
                        map.put("addScore", 0);
                    }

                    String[] ancestars = map.get("ancestors").toString().split(",");
                    if(ancestars.length>4)
                    {
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, "失败，最多只能添加到三级标签");
                        return result;
                    }

                    labelManageService.insert(map);

                    //新增指标设置数据
//                    Map<String, Object> eaadd = new HashMap<String, Object>();
//                    eaadd.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
//                    eaadd.put("compute", "+");
//                    eaadd.put("attribute", map.get("attribute"));
//                    eaadd.put("labelId", map.get("id"));
//                    eaadd.put("orderNum", 1);
//                    eaadd.put("createBy", "管理员");
//                    eaadd.put("createTime", DateTimeUtils.getTime());
//                    exponentialAlgorithmService.insert(eaadd);

                    //新增下级的时候 把上级的指数算法进行删除操作
                    Map<String, Object> eamap = new HashMap<String, Object>();
                    eamap.put("labelId", map.get("parentId").toString());//根据标签id删除算法表信息
                    exponentialAlgorithmService.deleteByMap(eamap);

                }
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, "失败，上级标签和标签名称为必填项");
                return result;
            }

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/update")
    @ApiOperation(value = "根据-{信用指数报告标签管理修改接口}-对象更新记录(标签管理和指数算法)", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理修改接口}-对象更新记录(标签管理和指数算法)", value = "update", type = "PC")
    public Map<String, Object> updateForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody LabelManageVo lab) {

        Map<String, Object> map = new HashMap<String, Object>();

        map.put("id",lab.getId());

        if(StringUtils.isNotBlank(lab.getParentId()))
        {
            map.put("parentId",lab.getParentId());
        }

        if(StringUtils.isNotBlank(lab.getLabelName()))
        {
            map.put("labelName",lab.getLabelName());
        }

        if(lab.getOrderNum()!=null)
        {
            map.put("orderNum",lab.getOrderNum());
        }

        if(StringUtils.isNotBlank(lab.getStatus()))
        {
            map.put("status",lab.getStatus());
        }

        if(lab.getScore()!=null)
        {
            map.put("score",lab.getScore());
        }

        if(lab.getAddScore()!=null)
        {
            map.put("addScore",lab.getAddScore());
        }

        if(lab.getBaseScore()!=null)
        {
            map.put("baseScore",lab.getBaseScore());
        }

        Map<String, Object> result = new HashMap<String, Object>();

        try {

            Map<String, Object> paramsmap = labelManageService.selectByPrimaryKey(map.get("id") + "");

            String ancestors = paramsmap.get("ancestors").toString();

            if (paramsmap.get("id").equals(map.get("parentId"))) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, "失败，上级标签不能是自己");
                return result;
            }

            Map<String, Object> map2 = new HashMap<String, Object>();

            if (map.get("status") != null) {
                if (map.get("status").equals("1")) {
                    map2.put("parentId", paramsmap.get("id").toString());
                    map2.put("status", "0");
                    Integer num = labelManageService.count(map2);

                    if (num > 0) {
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, "失败，有未停用的子标签");
                        return result;
                    }
                }
            }

            int flag = 0;

            if (null != paramsmap && paramsmap.size() > 0) {

                Map<String, Object> parent = labelManageService.selectByPrimaryKey(paramsmap.get("parentId") + "");

                paramsmap.put("ancestors", parent.get("ancestors") + "," + paramsmap.get("parentId"));

                if (lab.getEaList().size()==0) {

                    if (map.get("parentId") != null) {
                        paramsmap.put("parentId", map.get("parentId").toString());
                    }

                    if (map.get("labelName") != null) {
                        paramsmap.put("labelName", map.get("labelName").toString());
                    }

                    if (map.get("orderNum") != null) {
                        paramsmap.put("orderNum", map.get("orderNum"));
                    }

                    if (map.get("status") != null) {
                        paramsmap.put("status", map.get("status").toString());
                    }

                    if (map.get("delFlag") != null) {
                        paramsmap.put("delFlag", map.get("delFlag").toString());
                    }

                    if (map.get("score") != null) {
                        paramsmap.put("score", map.get("score"));
                    }

                    if (map.get("attribute") != null) {
                        paramsmap.put("attribute", map.get("attribute").toString());
                    }

                    if (map.get("baseScore") != null) {
                        paramsmap.put("baseScore", map.get("baseScore"));
                    }

                    if (map.get("addScore") != null) {
                        paramsmap.put("addScore", map.get("addScore"));
                    }

                    flag = labelManageService.update(paramsmap);
                }

                if (!paramsmap.get("ancestors").equals(ancestors)) {
                    Map<String, Object> map4 = new HashMap<String, Object>();
                    map4.put("parentId", paramsmap.get("id"));
                    map4.put("ancestors", paramsmap.get("ancestors") + "," + paramsmap.get("id"));
                    labelManageService.updateAncestors(map4);
                }

                paramsmap.putAll(map);

                if (lab.getEaList().size()>0) {

                    Map<String, Object> map3 = new HashMap<String, Object>();
                    map3.put("parentId", paramsmap.get("id"));
                    Integer num3 = labelManageService.count(map3);

                    if (num3 == 0) {
                        Map<String, Object> eamap = new HashMap<String, Object>();
                        eamap.put("labelId", map.get("id").toString());//根据标签id删除算法表信息
                        exponentialAlgorithmService.deleteByMap(eamap);

                        eamap.put("createBy", "管理员");
                        eamap.put("createTime", DateTimeUtils.getTime());

                        for (int i = 0; i < lab.getEaList().size(); i++) {

                            ExponentialAlgorithmVo e = lab.getEaList().get(i);

                            List<ExponentialAlgorithmVo> list = xyzsSelect();

                            String storeName = e.getAnnotate();

                            ExponentialAlgorithmVo ea = list.stream().filter(expensesBase -> storeName.equals(expensesBase.getAnnotate().toString())).findAny().orElse(null);

                            eamap.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                            eamap.put("compute", "+");
                            eamap.put("attribute", e.getAnnotate());
                            eamap.put("orderNum", ea.getOrderNum());
                            eamap.put("tableName", ea.getTableName());
                            eamap.put("annotate", e.getAnnotate());
                            eamap.put("xydm", ea.getXydm());
                            eamap.put("type", ea.getType());
                            eamap.put("typeName", ea.getTypeName());
                            eamap.put("rq", ea.getRq());
                            eamap.put("score",0);

                            flag = exponentialAlgorithmService.insert(eamap);
                        }


                    } else {

                        Map<String, Object> eamap = new HashMap<String, Object>();
                        eamap.put("labelId", paramsmap.get("id").toString());//根据标签id删除算法表信息
                        exponentialAlgorithmService.deleteByMap(eamap);

                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, "失败，只有子标签才能设置指数算法");
                        return result;
                    }

                }

            }

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteByMap")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteByMapForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = labelManageService.deleteByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateByMap")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map更新记录", value = "update", type = "PC")
    public Map<String, Object> updateByMapForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            int flag = labelManageService.updateByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getOne")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map查询记录", value = "query", type = "PC")
    public Map<String, Object> getOneForlabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, labelManageService.getOne(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getAll")
    @ApiOperation(value = "根据-{信用指数报告标签管理列表查看页面}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理列表查看页面}-对象Map查询所有记录", value = "query", type = "PC")
    public Map<String, Object> getAllForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            List<Map<String, Object>> treedata = labelManageService.getAll(map);

            List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

            if (null != treedata && treedata.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : treedata) {

                    tree.put("parentId", tree.get("parentId"));
                    tree.put("id", tree.get("id"));

                    if (tree.get("parentId").equals("1")) {
                        tree.put("baseScore", "");
                        tree.put("addScore", "");
                        parenttreedata.add(tree);
                    }

                }

                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点

                for (Map<String, Object> ptree : parenttreedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {

                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));

                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            second_treedata.add(tree);
                            tree.put("addScore", "");
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                    for (Map<String, Object> tree : treedata) {

                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));

                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            third_treedata.add(tree);
                            tree.put("baseScore", "");
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点

                //四级树节点
                for (Map<String, Object> ptree : third_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            fourth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //五级树节点
                for (Map<String, Object> ptree : fourth_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            fifth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点

                //六级树节点
                for (Map<String, Object> ptree : fifth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            sixth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //七级树节点
                for (Map<String, Object> ptree : sixth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            seventh_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //八级树节点
                for (Map<String, Object> ptree : seventh_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            eighth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //九级树节点
                for (Map<String, Object> ptree : eighth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            nineth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //十级树节点
                for (Map<String, Object> ptree : nineth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("parentId", tree.get("parentId"));
                        tree.put("id", tree.get("id"));
                        if (tree.get("parentId").equals(ptree.get("id"))) {
                            tenth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
            }

            result.put(DATALIST, parenttreedata);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            //result.put(DATALIST, labelManageService.getAll(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/queryPage")
    @ApiOperation(value = "根据-{企业信用风险自定义预警设置}-对象Map分页记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{企业信用风险自定义预警设置}-对象Map分页记录", value = "query", type = "PC")
    public Map<String, Object> queryPageForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            int currentPage = map.get(DATACURRENT) != null ? Integer.parseInt(map.get(DATACURRENT) + "") - 1 : 0;
            int pageSize = map.get(PAGESIZE) != null ? Integer.parseInt(map.get(PAGESIZE) + "") : 10;
            int pageStart = currentPage * pageSize;

            map.put(PAGESIZE, pageSize);
            map.put(PAGESTART, pageStart);

            int total = labelManageService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if (total > 0) {
                datalist = labelManageService.queryPage(map);
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST, datalist);
            tempresult.put(DATATOTAL, total);
            tempresult.put(PAGESIZE, map.get(PAGESIZE) != null ? map.get(PAGESIZE) : 10);
            tempresult.put(DATACURRENT, map.get(DATACURRENT) != null ? map.get(DATACURRENT) : 0);
            result.put(DATARESULT, tempresult);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/count")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map统计查询总数记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map统计查询总数记录", value = "query", type = "PC")
    public Map<String, Object> countForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATATOTAL, labelManageService.count(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insertBatch")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map批量插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map批量插入记录", value = "insert", type = "PC")
    public Map<String, Object> insertBatchForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            for (Map<String, Object> map : list) {
                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
            }

            labelManageService.insertBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteBatch")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map批量删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map批量删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteBatchForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            labelManageService.deleteBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateBatch")
    @ApiOperation(value = "根据-{信用指数报告标签管理}-对象Map批量更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{信用指数报告标签管理}-对象Map批量更新记录", value = "update", type = "PC")
    public Map<String, Object> updateBatchForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            labelManageService.updateBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    @GetMapping("/export")
    @ApiOperation(value = "根据-{{信用指数报告标签管理}}-对象Map导出所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告标签管理}}-对象Map导出所有记录", value = "query", type = "PC")
    public void exportForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            List<Map<String, Object>> rows = labelManageService.getAll(map);
            // 通过工具类创建writer
            //创建xlsx格式的
            ExcelWriter writer = ExcelUtil.getWriter(true);
            String filename = "信用指数报告标签管理";
            getWriter(writer, filename);
            writer.setHeaderAlias(getKVAliasMap());


            writer.setOnlyAlias(true);

            // 一次性写出内容，使用默认样式，强制输出标题
            writer.write(rows, true);

            //response为HttpServletResponse对象
            response.setContentType("application/vnd.ms-excel;charset=utf-8");
            //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
            response.setHeader("Content-Disposition", "attachment;filename=" + filename + "_LabelManage.xlsx");
            ServletOutputStream out = response.getOutputStream();
            writer.flush(out, true);
            // 关闭writer，释放内存
            writer.close();
            //此处记得关闭输出Servlet流
            IoUtil.close(out);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
    }


    @GetMapping("/exportTemplate")
    @ApiOperation(value = "根据-{{信用指数报告标签管理}}-下载导出模板", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告标签管理}}-下载导出模板", value = "query", type = "PC")
    public void exportTemplateForLabelManageForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String filename = "信用指数报告标签管理";
            InputStream resource = getClass().getClassLoader().getResourceAsStream("excelTemplate/LabelManage" + "/" + filename + "_LabelManage.xlsx");
            //response为HttpServletResponse对象
            response.setContentType("application/vnd.ms-excel;charset=utf-8");
            //test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
            response.setHeader("Content-Disposition", "attachment;filename=" + filename + "_EnterpriseWarning.xlsx");
            ServletOutputStream out = response.getOutputStream();
            IoUtil.copy(resource, out);
            //此处记得关闭输出Servlet流
            IoUtil.close(out);
            IoUtil.close(resource);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
    }


    @PostMapping("/importExcel")
    @ApiOperation(value = "根据-{{信用指数报告标签管理}}-对象Map批量导入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = LabelManage.ID_KEY, value = "主键 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.PARENT_ID, value = "父部门id ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ANCESTORS, value = "祖级列表  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.LABEL_NAME, value = "标签名称 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ORDER_NUM, value = "显示顺序  ", required = true, dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.STATUS, value = "标签状态 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.DEL_FLAG, value = "删除标志  ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_BY, value = "创建者 ", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.CREATE_TIME, value = "创建时间  ", required = true, dataTypeClass = Date.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.SCORE, value = "权重分值  ", required = true, dataTypeClass = Double.class),
            @ApiImplicitParam(paramType = "body", name = LabelManage.ATTRIBUTE, value = "属性 ", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{{信用指数报告标签管理}}-对象Map批量导入记录", value = "update", type = "PC")
    public Map<String, Object> importExcelForLabelManageForWeb(String baseDir, MultipartFile file) {
        Map<String, Object> result = new HashMap<String, Object>();

        if (!file.isEmpty()) {
            try {
                ExcelReader reader = ExcelUtil.getReader(file.getInputStream());

                reader.setHeaderAlias(getVKAliasMap());


                List<Map<String, Object>> list = new ArrayList<>();
                List<Map<String, Object>> read = reader.read(1, 2, Integer.MAX_VALUE);

                for (Map<String, Object> map : read) {


                    if ("".equals(map.get(LabelManage.ID_KEY))) {
                        map.put(LabelManage.ID_KEY, null);
                    }

                    if ("".equals(map.get(LabelManage.PARENT_ID))) {
                        map.put(LabelManage.PARENT_ID, null);
                    }

                    if ("".equals(map.get(LabelManage.ANCESTORS))) {
                        map.put(LabelManage.ANCESTORS, null);
                    }

                    if ("".equals(map.get(LabelManage.LABEL_NAME))) {
                        map.put(LabelManage.LABEL_NAME, null);
                    }

                    if ("".equals(map.get(LabelManage.ORDER_NUM))) {
                        map.put(LabelManage.ORDER_NUM, null);
                    }

                    if ("".equals(map.get(LabelManage.STATUS))) {
                        map.put(LabelManage.STATUS, null);
                    }

                    if ("".equals(map.get(LabelManage.DEL_FLAG))) {
                        map.put(LabelManage.DEL_FLAG, null);
                    }

                    if ("".equals(map.get(LabelManage.CREATE_BY))) {
                        map.put(LabelManage.CREATE_BY, null);
                    }

                    if ("".equals(map.get(LabelManage.CREATE_TIME))) {
                        map.put(LabelManage.CREATE_TIME, null);
                    }

                    if ("".equals(map.get(LabelManage.SCORE))) {
                        map.put(LabelManage.SCORE, null);
                    }

                    list.add(map);

                }
                labelManageService.insertBatch(list);

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG);
        return result;
    }


    protected void getWriter(ExcelWriter writer, String filename) {
        // 通过工具类创建writer
        //创建xlsx格式的
        writer.setColumnWidth(0, 25);
        writer.setColumnWidth(1, 25);
        writer.setColumnWidth(2, 25);
        writer.setColumnWidth(3, 25);
        writer.setColumnWidth(4, 25);
        writer.setColumnWidth(5, 25);
        writer.setColumnWidth(6, 25);
        writer.setColumnWidth(7, 25);
        writer.setColumnWidth(8, 25);
        writer.setColumnWidth(9, 25);
        writer.setColumnWidth(10, 25);
        // 合并单元格后的标题行，使用默认标题样式
        writer.merge(10, filename);

    }


    protected Map<String, String> getKVAliasMap() {

        Map<String, String> aliasMap = new LinkedHashMap<>();

        aliasMap.put(LabelManage.ID_KEY, "主键 ");
        aliasMap.put(LabelManage.PARENT_ID, "父部门id ");
        aliasMap.put(LabelManage.ANCESTORS, "祖级列表  ");
        aliasMap.put(LabelManage.LABEL_NAME, "标签名称 ");
        aliasMap.put(LabelManage.ORDER_NUM, "显示顺序 ");
        aliasMap.put(LabelManage.STATUS, "标签状态  ");
        aliasMap.put(LabelManage.DEL_FLAG, "删除标志 ");
        aliasMap.put(LabelManage.CREATE_BY, "创建者  ");
        aliasMap.put(LabelManage.CREATE_TIME, "创建时间 ");
        aliasMap.put(LabelManage.SCORE, "权重分值 ");
        aliasMap.put(LabelManage.ATTRIBUTE, "属性 ");
        return aliasMap;

    }

    protected Map<String, String> getVKAliasMap() {
        Map<String, String> aliasMap = new LinkedHashMap<>();

        aliasMap.put("主键 ", LabelManage.ID_KEY);
        aliasMap.put("父部门id ", LabelManage.PARENT_ID);
        aliasMap.put("祖级列表  ", LabelManage.ANCESTORS);
        aliasMap.put("标签名称 ", LabelManage.LABEL_NAME);
        aliasMap.put("显示顺序 ", LabelManage.ORDER_NUM);
        aliasMap.put("标签状态  ", LabelManage.STATUS);
        aliasMap.put("删除标志 ", LabelManage.DEL_FLAG);
        aliasMap.put("创建者 ", LabelManage.CREATE_BY);
        aliasMap.put("创建时间  ", LabelManage.CREATE_TIME);
        aliasMap.put("权重分值  ", LabelManage.SCORE);
        aliasMap.put("属性  ", LabelManage.ATTRIBUTE);
        return aliasMap;
    }


}
