package com.philisense.www.controller.web;

import cn.hutool.core.io.IoUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.PersonnelAnalysisService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"personnelanalysis")
@Api(tags = "PersonnelAnalysisControllerForWeb|一个用来操作-{失信被执行关联分析}-业务模块的控制器")
public class PersonnelAnalysisControllerForWeb extends BaseUtilController{

        @Autowired
        private PersonnelAnalysisService personnelAnalysisService;

        //预警列表
        @PostMapping( "/selectSxglfxList")
        @ApiOperation(value="根据-{失信被执行关联分析列表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "zzmc", value = "企业名称 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "fddbrxm", value = "法人  ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "zs", value = "住所  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{失信被执行关联分析列表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  selectSxglfxList(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        map.put(PAGESIZE,pageSize);
                        map.put(PAGESTART,pageStart);

                        int total = personnelAnalysisService.selectSxglfxCount(map);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = personnelAnalysisService.selectSxglfxList(map);
                        }
                        Map<String, Object> tempresult = new HashMap<String, Object>();
                        tempresult.put(DATASUCCESS, SUCCESSFLAG);
                        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        tempresult.put(DATALIST,datalist);
                        tempresult.put(DATATOTAL,total);
                        tempresult.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                        tempresult.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                        result.put(DATARESULT, tempresult);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //查询该人员关联的企业（即该人员是否在其他企业持股当股东）
        @PostMapping( "/selectQycggdList")
        @ApiOperation(value="根据-{失信被执行关联分析列表}-查询该人员关联的企业", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "bzxr", value = "被执行人 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "dmhzjhm", value = "代码或证件号码  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{失信被执行关联分析列表}-查询该人员关联的企业",value = "query",type = "PC")
        public Map<String, Object>  selectQycggdList(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        List<Map<String, Object>> list = personnelAnalysisService.selectQycggdList(map);
                        result.put("data", list);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        //点击详情返回该失信被执行人的详细信息
        @PostMapping( "/selectSxryxqList")
        @ApiOperation(value="根据-{失信被执行关联分析列表}-失信被执行人的详细信息", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "bzxr", value = "被执行人 ", required = true, dataTypeClass = String.class),
                @ApiImplicitParam(paramType="body", name = "dmhzjhm", value = "代码或证件号码  ", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{失信被执行关联分析列表}-失信被执行人的详细信息",value = "query",type = "PC")
        public Map<String, Object>  selectSxryxqList(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        List<Map<String, Object>> list1 = personnelAnalysisService.selectJtxxList(map);
                        List<Map<String, Object>> list2 = personnelAnalysisService.selectZyxxList(map);
                        List<Map<String, Object>> list3 = personnelAnalysisService.selectJyxxList(map);
                        List<Map<String, Object>> list4 = personnelAnalysisService.selectHjxxList(map);
                        result.put("jtxx", list1);//家庭信息
                        result.put("zyxx", list2);//职业信息
                        result.put("jyxx", list3);//教育信息
                        result.put("hjxx", list4);//户籍信息
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }
}
