package com.philisense.www.filters;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.contant.Const;
import com.philisense.www.core.text.Convert;
import com.philisense.www.utils.ActiveUserUtils;
import com.philisense.www.utils.RestTemplateUtils;
import com.philisense.www.utils.ServletUtils;
import com.philisense.www.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.web.client.RestTemplate;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 验权
 *
 * @author
 */
@WebFilter(filterName = "authFilter", urlPatterns = {"/web/api/service/*", "/app/api/service/*"})
public class AuthFilter implements Filter {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    @Qualifier("remoteRPCRestTemplate")
    private RestTemplate remoteRPCRestTemplate;

    @Value("${httpclient.platformsystemserverpath}")
    private String platformSystemServerPath;

    @Override
    public void init(FilterConfig filterConfig) throws ServletException {
    }

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain chain) throws IOException, ServletException {
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;

        String path = request.getServletPath();

        if(path.equals("/web/api/service/labelmanage/installTreeDexreportForWord") || path.equals("/web/api/service/enterpriseinformationpublicity/installCreditReportWord"))
        {
            chain.doFilter(request, response);
        }

        String queryString = request.getQueryString();
        Boolean isAuth = false;
        if (!StringUtils.isBlank(queryString)) {
            path = path + "?" + queryString;
        }
        if (path.matches(Const.NO_INTERCEPTOR_PATH)) {
            isAuth = true;
        }

        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("uri", request.getServletPath());
        paramMap.put("systemid", "000000000004");

        HttpEntity<Map<String,Object>> httpEntity = new HttpEntity<>(paramMap, RestTemplateUtils.handleHeaders(request, Const.TOKEN_HEADER));
        String url = platformSystemServerPath + CommonConst.WEB_REST_SERVICE_PREFICX + "auth/verifyToken";
        Map<String, Object> bodyResult = remoteRPCRestTemplate.postForObject(url, httpEntity, Map.class);
        logger.info("AuthFilter.doFilter() 校验Token返回参数：{}", bodyResult);
        if (StringUtils.isNotNull(bodyResult) && Convert.toBool(bodyResult.get("success"))) {
            isAuth = true;
            JSONObject dataRecord = JSONObject.parseObject(JSONObject.toJSONString(bodyResult.get("datarecord")));
            if(StringUtils.isNotNull(dataRecord)) {
                ActiveUserUtils.activeUserMap.putAll(dataRecord.getJSONObject("user"));
            }
        }

        // 验证是否有权限
        if (isAuth) {
            chain.doFilter(request, response);
        } else {
            ServletUtils.renderString(response, JSON.toJSONString(bodyResult));
        }
    }

    @Override
    public void destroy() {
    }
}
