package com.philisense.www.service.impl;

import com.philisense.www.dao.ComprehensiveStatisticalAnalysisDAO;
import com.philisense.www.service.ComprehensiveStatisticalAnalysisService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.NumberFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Administrator
 */
@Service
public class ComprehensiveStatisticalAnalysisServiceImpl implements ComprehensiveStatisticalAnalysisService {

    @Autowired
    private ComprehensiveStatisticalAnalysisDAO comprehensiveStatisticalAnalysisDAO;

    @Override
    public List<Map<String, String>> selectEarlyWarningData(String startTime, String endTime) {
        if (startTime == null || "".equals(startTime) && (endTime == null || "".equals(endTime))){
            Integer year = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.YEAR)));
            Integer Month = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.MONTH)));
            Month++;
            startTime = year + "-01";
            if(Month <= 9){
                endTime = year + "-0" + Month;
            }else{
                endTime = year + "-" + Month;
            }
        }
        return comprehensiveStatisticalAnalysisDAO.selectEarlyWarningData(startTime, endTime);
    }

    @Override
    public List<Map<String, String>> selectIndustryCreditIndexData(String startTime, String endTime) {
        if (startTime == null || "".equals(startTime) && (endTime == null || "".equals(endTime))){
            Integer year = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.YEAR)));
            Integer Month = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.MONTH)));
            Month++;
            startTime = year + "-01";
            if(Month <= 9){
                endTime = year + "-0" + Month;
            }else{
                endTime = year + "-" + Month;
            }
        }
        List<Map<String, String>> list = comprehensiveStatisticalAnalysisDAO.selectIndustryCreditIndexData(startTime, endTime);
        double sum = 0;
        for (Map map: list) {
            sum += (Float)map.get("value");
        }
        NumberFormat nf = NumberFormat.getPercentInstance();
        nf.setMinimumFractionDigits(2);
        if( sum != 0 ){
            for (Map map: list) {
                Float score =  (Float)map.get("value");
                map.put("percent",nf.format(score/sum));
            }
        }

        return list;
    }

    @Override
    public List<Map<String, String>> selectAreaEarlyWarningData(String startTime, String endTime) {
        if (startTime == null || "".equals(startTime) && (endTime == null || "".equals(endTime))){
            Integer year = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.YEAR)));
            Integer Month = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.MONTH)));
            Month++;
            startTime = year + "-01";
            if(Month <= 9){
                endTime = year + "-0" + Month;
            }else{
                endTime = year + "-" + Month;
            }
        }
        List<Map<String, String>> list = comprehensiveStatisticalAnalysisDAO.selectAreaEarlyWarningData(startTime, endTime);
        String[] arr = {"那曲市","拉萨市","林芝市","昌都市","山南市","日喀则市","阿里地区"};
        int i;
        for(String str:arr){
            i=0;
            for(Map map:list){
                String name = (String)map.get("name");
                if(str.equals(name)){
                    i=1;
                    break;
                }
            }
            if(i==1){
                continue;
            }else{
                Map map = new HashMap();
                map.put("name",str);
                map.put("value",0);
                list.add(map);
            }

        }

        return list;
    }

    @Override
    public List<Map<String, String>> selectAreaEarlyWarningData1(String startTime, String endTime) {
        if (startTime == null || "".equals(startTime) && (endTime == null || "".equals(endTime))){
            Integer year = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.YEAR)));
            Integer Month = Integer.parseInt(String.valueOf(Calendar.getInstance().get(Calendar.MONTH)));
            Month++;
            startTime = year + "-01";
            if(Month <= 9){
                endTime = year + "-0" + Month;
            }else{
                endTime = year + "-" + Month;
            }
        }
        Integer year1 = Integer.parseInt(startTime.substring(0,4));
        Integer year2 = Integer.parseInt(endTime.substring(0,4));
        Integer month1 = Integer.parseInt(startTime.substring(startTime.length()-2,startTime.length()));
        Integer month2 = Integer.parseInt(endTime.substring(startTime.length()-2,endTime.length()));
        List<Map<String, String>> list = comprehensiveStatisticalAnalysisDAO.selectAreaEarlyWarningData1(startTime, endTime);
        for(int i=0; year1 <= year2  ;i++ ){
            if(i<list.size()){
                Map map = list.get(i);
                String name = (String)map.get("name");
                if(month1 <= 9){
                    if(!name.equals(year1 + "-0" + month1)){
                        Map map1 = new HashMap();
                        map1.put("name",year1 + "-0" + month1);
                        map1.put("value",0);
                        list.add(i,map1);
                    }
                }else{
                    if(!name.equals(year1 + "-" + month1)){
                        Map map1 = new HashMap();
                        map1.put("name",year1 + "-" + month1);
                        map1.put("value",0);
                        list.add(i,map1);
                    }
                }
            }else{
                if(month1 <= 9){
                    Map map1 = new HashMap();
                    map1.put("name",year1 + "-0" + month1);
                    map1.put("value",0);
                    list.add(i,map1);
                }else{
                    Map map1 = new HashMap();
                    map1.put("name",year1 + "-" + month1);
                    map1.put("value",0);
                    list.add(i,map1);
                }
            }
            if(year1.equals(year2) && month1.equals(month2)){
                break;
            }

            if(month1 == 12){
                year1++;
                month1 = 1;
            }else{
                month1++;
            }
        }
        return list;
    }
}
